@@ -3,21 +3,19 @@
 """ A multi-platform object drawing library.
     Part of the Enable project of the Enthought Tool Suite.
 """
-import sys
 from ._version import full_version as __version__
 
-__all__ = [
-    '__version__',
-]
-
 __requires__ = [
     'numpy',
     'traits',
     'traitsui',
-    'PIL',
     'pyface',
+    'six',
+    'fonttools'
 ]
 
-# Cython is only necessary to build the quartz backend.
-if sys.platform == 'darwin':
-    __requires__.append('cython')
+# Do not force installation of pillow if PIL is already available.
+try:
+    import PIL
+except ImportError:
+    __requires__.append('pillow')
