@@ -1,5 +1,6 @@
 
 # Major library imports
+import six.moves as sm
 from numpy import dot
 
 # Enthought library imports
@@ -8,12 +9,12 @@ from traits.api import Any, Bool, Event, HasTraits, Instance, \
 
 
 # Local relative imports
-from base import bounds_to_coordinates, does_disjoint_intersect_coordinates, \
+from .base import bounds_to_coordinates, does_disjoint_intersect_coordinates, \
     union_bounds
-from component import Component
-from interactor import Interactor
-from container import Container
-from colors import ColorTrait
+from .component import Component
+from .interactor import Interactor
+from .container import Container
+from .colors import ColorTrait
 
 def Alias(name):
     return Property(lambda obj: getattr(obj, name),
@@ -75,6 +76,8 @@ class AbstractWindow(HasTraits):
     # The regions to update upon redraw
     _update_region = Any
 
+    # When exceeding this, the entire window is marked damaged to save memory
+    MAX_DAMAGED_REGIONS = 100
 
 
     #---------------------------------------------------------------------------
@@ -100,7 +103,7 @@ class AbstractWindow(HasTraits):
     def _create_key_event(self, event):
         "Convert a GUI toolkit key event into a KeyEvent"
         raise NotImplementedError
-    
+
     def _create_mouse_event(self, event):
         "Convert a GUI toolkit mouse event into a MouseEvent"
         raise NotImplementedError
@@ -134,7 +137,7 @@ class AbstractWindow(HasTraits):
             gc.clear(self.bgcolor_)
         else:
             # Fixme: should use clip_to_rects
-            update_union = reduce(union_bounds, self._update_region)
+            update_union = sm.reduce(union_bounds, self._update_region)
             gc.clip_to_rect(*update_union)
         return
 
@@ -161,7 +164,7 @@ class AbstractWindow(HasTraits):
     def get_pointer_position(self):
         "Returns the current pointer position in local window coordinates"
         raise NotImplementedError
-        
+
     #------------------------------------------------------------------------
     # Public methods
     #------------------------------------------------------------------------
@@ -231,7 +234,8 @@ class AbstractWindow(HasTraits):
         return
 
     def invalidate_draw(self, damaged_regions=None, self_relative=False):
-        if damaged_regions is not None and self._update_region is not None:
+        if damaged_regions is not None and self._update_region is not None \
+                and len(self._update_region) < self.MAX_DAMAGED_REGIONS:
             self._update_region += damaged_regions
         else:
             self._update_region = None
@@ -244,7 +248,7 @@ class AbstractWindow(HasTraits):
         """ **event** should be a toolkit-specific opaque object that will
         be passed in to the backend's _create_key_event() method. It can
         be None if the the toolkit lacks a native "key event" object.
-        
+
         Returns True if the event has been handled within the Enable object
         hierarchy, or False otherwise.
         """
@@ -252,11 +256,11 @@ class AbstractWindow(HasTraits):
         key_event = self._create_key_event(event_type, event)
         if key_event is None:
             return False
-        
+
         self.shift_pressed = key_event.shift_down
         self.alt_pressed = key_event.alt_down
         self.control_pressed = key_event.control_down
-        
+
         # Dispatch the event to the correct component
         mouse_owner = self.mouse_owner
         if mouse_owner is not None:
@@ -264,7 +268,7 @@ class AbstractWindow(HasTraits):
             if history is not None and len(history) > 0:
                 # Assemble all the transforms
                 transforms = [c.get_event_transform() for c in history]
-                total_transform = reduce(dot, transforms[::-1])
+                total_transform = sm.reduce(dot, transforms[::-1])
                 key_event.push_transform(total_transform)
             elif self.mouse_owner_transform is not None:
                 key_event.push_transform(self.mouse_owner_transform)
@@ -276,7 +280,7 @@ class AbstractWindow(HasTraits):
                 if self.component.is_in(key_event.x, key_event.y):
                     # Fire the actual event
                     self.component.dispatch(key_event, event_type)
-        
+
         return key_event.handled
 
     #---------------------------------------------------------------------------
@@ -301,7 +305,7 @@ class AbstractWindow(HasTraits):
         # if no mouse event generated for some reason, return
         if mouse_event is None:
             return False
-        
+
         mouse_owner = self.mouse_owner
 
         if mouse_owner is not None:
@@ -313,7 +317,7 @@ class AbstractWindow(HasTraits):
             if history is not None and len(history) > 0:
                 # Assemble all the transforms
                 transforms = [c.get_event_transform() for c in history]
-                total_transform = reduce(dot, transforms[::-1])
+                total_transform = sm.reduce(dot, transforms[::-1])
                 mouse_event.push_transform(total_transform)
             elif self.mouse_owner_transform is not None:
                 mouse_event.push_transform(self.mouse_owner_transform)
@@ -388,7 +392,7 @@ class AbstractWindow(HasTraits):
         # if no mouse event generated for some reason, return
         if drag_event is None:
             return False
-            
+
         if self.component is not None:
             # Test to see if we need to generate a drag_leave event
             if self._prev_event_handler:
@@ -559,5 +563,3 @@ class AbstractWindow(HasTraits):
 
     def _on_character(self, event):
         self._handle_key_event('character', event)
-
-
