@@ -14,7 +14,7 @@
 
 
 # Import the toolkit specific version.
-from toolkit import toolkit_object
+from .toolkit import toolkit_object
 CompiledPath = toolkit_object('CompiledPath')
 
 #### EOF ######################################################################
