@@ -11,10 +11,10 @@ from traits.api \
 from kiva.constants import FILL, STROKE
 
 # Local relative imports
-from colors import black_color_trait, white_color_trait
-from coordinate_box import CoordinateBox
-from enable_traits import bounds_trait, coordinate_trait, LineStyle
-from interactor import Interactor
+from .colors import black_color_trait, white_color_trait
+from .coordinate_box import CoordinateBox
+from .enable_traits import bounds_trait, coordinate_trait, LineStyle
+from .interactor import Interactor
 
 
 coordinate_delegate = Delegate("inner", modify=True)
@@ -376,21 +376,24 @@ class Component(CoordinateBox, Interactor):
         # may override the bulk default.
         padding = traits.pop('padding', None)
         padding_traits = {}
-        for name in traits.keys():
-            # Use .keys() so we can modify the dict during iteration safely.
-            if name in ['padding_top', 'padding_bottom', 'padding_left',
-                'padding_right']:
+        for name in ['padding_top',
+                     'padding_bottom',
+                     'padding_left',
+                     'padding_right']:
+            try:
                 padding_traits[name] = traits.pop(name)
+            except KeyError:
+                pass
 
-        if traits.has_key("container"):
+        if "container" in traits:
             # After the component is otherwise configured, make sure our
             # container gets notified of our being added to it.
             container = traits.pop("container")
-            super(Component,self).__init__(**traits)
+            super(Component, self).__init__(**traits)
             self._set_padding_traits(padding, padding_traits)
             container.add(self)
         else:
-            super(Component,self).__init__(**traits)
+            super(Component, self).__init__(**traits)
             self._set_padding_traits(padding, padding_traits)
         return
 
@@ -467,15 +470,15 @@ class Component(CoordinateBox, Interactor):
             width -= 2*inset
             height -= 2*inset
             rect = (x, y, width, height)
-    
+
             gc.set_stroke_color(bgcolor)
             gc.set_line_dash(None)
             gc.draw_rect(rect, STROKE)
-    
+
             gc.set_stroke_color(color)
             gc.set_line_dash(dash)
             gc.draw_rect(rect, STROKE)
-    
+
             if marker_size > 0:
                 gc.set_fill_color(bgcolor)
                 half_y = y + height/2.0
@@ -510,7 +513,7 @@ class Component(CoordinateBox, Interactor):
         else:
             offset_x, offset_y = self.position
         return (offset_x + coords[0], offset_y + coords[1])
- 
+
     def get_relative_coords(self, *coords):
         """ Given absolute coordinates (where the origin is the top-left corner
         of the frame in the top-level parent Window) return coordinates relative
@@ -1088,9 +1091,9 @@ class Component(CoordinateBox, Interactor):
                 new_pos = self.position[:]
                 new_pos[0] += (old_w - new_w) / 2.0
 
-        self.set(bounds=[new_w, new_h], trait_change_notify=notify)
+        self.trait_set(bounds=[new_w, new_h], trait_change_notify=notify)
         if new_pos:
-            self.set(position=new_pos, trait_change_notify=notify)
+            self.trait_set(position=new_pos, trait_change_notify=notify)
         return
 
     def _bounds_changed(self, old, new):
