@@ -11,9 +11,9 @@ from traits.api import Any, Bool, Enum, HasTraits, Instance, List, \
         Property, Tuple
 
 # Local, relative imports
-from base import empty_rectangle, intersect_bounds
-from component import Component
-from events import BlobEvent, BlobFrameEvent, DragEvent, MouseEvent
+from .base import empty_rectangle, intersect_bounds
+from .component import Component
+from .events import BlobEvent, BlobFrameEvent, DragEvent, MouseEvent
 
 
 class Container(Component):
@@ -101,7 +101,7 @@ class Container(Component):
         Component.__init__(self, **traits)
         for component in components:
             self.add(component)
-        if "bounds" in traits.keys() and "auto_size" not in traits.keys():
+        if "bounds" in traits and "auto_size" not in traits:
             self.auto_size = False
 
         if 'intercept_events' in traits:
@@ -130,7 +130,7 @@ class Container(Component):
                 component.container = None
                 self._components.remove(component)
             else:
-                raise RuntimeError, "Unable to remove component from container."
+                raise RuntimeError("Unable to remove component from container.")
 
             # Check to see if we need to compact.
             if self.auto_size:
@@ -199,8 +199,9 @@ class Container(Component):
             # Update our position and the positions of all of our components,
             # but do it quietly
             for component in self._components:
-                component.set(position = [component.x-ll_x, component.y-ll_y],
-                              trait_change_notify = False)
+                component.trait_setq(
+                    position=[component.x-ll_x, component.y-ll_y]
+                )
 
             # Change our position (in our parent's coordinate frame) and
             # update our bounds
@@ -589,7 +590,7 @@ class Container(Component):
         """
         with gc:
             gc.set_antialias(False)
-    
+
             self._draw_container(gc, mode)
             self._draw_background(gc, view_bounds, mode)
             self._draw_underlay(gc, view_bounds, mode)
