@@ -3,6 +3,7 @@ Define the event objects and traits used by Enable components.
 
 For a list of all the possible event suffixes, see interactor.py.
 """
+import six.moves as sm
 
 # Major library imports
 from numpy import array, dot
@@ -103,7 +104,7 @@ class BasicEvent(HasTraits):
         if len(self._transform_stack) == 0:
             return affine.affine_identity()
         else:
-            return reduce(dot, self._transform_stack[::-1])
+            return sm.reduce(dot, self._transform_stack[::-1])
 
     def current_pointer_position(self):
         """
@@ -118,14 +119,17 @@ class BasicEvent(HasTraits):
             self.y, self.handled)
         return s
 
+
 class MouseEvent(BasicEvent):
-    alt_down     = ReadOnly
+    alt_down = ReadOnly
     control_down = ReadOnly
-    shift_down   = ReadOnly
-    left_down    = ReadOnly
-    middle_down  = ReadOnly
-    right_down   = ReadOnly
-    mouse_wheel  = ReadOnly
+    shift_down = ReadOnly
+    left_down = ReadOnly
+    middle_down = ReadOnly
+    right_down = ReadOnly
+    mouse_wheel = ReadOnly
+    mouse_wheel_axis = ReadOnly
+    mouse_wheel_delta = ReadOnly
 
 mouse_event_trait = Event(MouseEvent)
 
