@@ -1,17 +1,19 @@
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  Copyright (c) 2014, Enthought, Inc.
 #  All rights reserved.
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 from abc import ABCMeta
 
+import six
+
 import kiwisolver as kiwi
 
 
+@six.add_metaclass(ABCMeta)
 class LinearSymbolic(object):
     """ An abstract base class for testing linear symbolic interfaces.
 
     """
-    __metaclass__ = ABCMeta
 
 
 LinearSymbolic.register(kiwi.Variable)
