@@ -2,6 +2,8 @@
 
 
 # Standard library imports.
+from __future__ import print_function
+
 import math
 
 # Enthought library imports.
@@ -55,7 +57,7 @@ class Shape(Component):
     def normal_key_pressed(self, event):
         """ Event handler. """
 
-        print 'normal_key_pressed', event.character
+        print('normal_key_pressed', event.character)
 
         return
 
@@ -148,9 +150,10 @@ class Shape(Component):
     # Protected 'Shape' interface
     ###########################################################################
 
-    def _distance_between(self, (x1, y1), (x2, y2)):
+    def _distance_between(self, point_1, point_2):
         """ Return the distance between two points. """
-
+        (x1, y1) = point_1
+        (x2, y2) = point_2
         return math.sqrt(pow(x1 - x2, 2) + pow(y1 - y2, 2))
 
     def _draw_text(self, gc):
