@@ -1,7 +1,6 @@
 
-from window import Window
+from .window import Window
 # from scrollbar import NativeScrollBar
 
 class NativeScrollBar(object):
     pass
-
