@@ -13,9 +13,11 @@ from __future__ import absolute_import
 
 import warnings
 
+import six.moves as sm
+
 from pyface.qt import QtCore
 
-from ..toolkit_constants import key_names, pointer_names
+from ..toolkit_constants import key_names, mouse_wheel_axes_names, pointer_names
 
 DRAG_RESULTS_MAP = { "error":   QtCore.Qt.IgnoreAction,
                      "none":    QtCore.Qt.IgnoreAction,
@@ -28,6 +30,9 @@ BUTTON_NAME_MAP = {
     QtCore.Qt.LeftButton:   "left",
     QtCore.Qt.RightButton:  "right",
     QtCore.Qt.MidButton:    "middle",
+    QtCore.Qt.XButton1:     "back",
+    QtCore.Qt.XButton2:     "forward",
+    QtCore.Qt.NoButton:     "none",
 }
 
 # TODO: Create bitmap cursor for the following:
@@ -79,7 +84,7 @@ pointer_shapes = [
 if len(pointer_names) != len(pointer_shapes):
     warnings.warn("The Qt4 toolkit backend pointer map is out of sync!")
 
-POINTER_MAP = dict(zip(pointer_names, pointer_shapes))
+POINTER_MAP = dict(sm.zip(pointer_names, pointer_shapes))
 
 KEY_MAP = {
     QtCore.Qt.Key_Backspace: 'Backspace',
@@ -148,3 +153,7 @@ for enum_name in dir(QtCore.Qt):
             continue
         key_name = enum_name[len('Key_'):]
         KEY_MAP[enum] = key_name
+
+# set up mouse wheel axes constants
+mouse_wheel_axes = [QtCore.Qt.Vertical, QtCore.Qt.Horizontal]
+MOUSE_WHEEL_AXIS_MAP = dict(zip(mouse_wheel_axes, mouse_wheel_axes_names))
