@@ -3,7 +3,7 @@ Define a standard horizontal and vertical Enable scrollbar component that wraps
 the standard Qt one.
 """
 
-from types import ListType, TupleType
+import six.moves as sm
 
 from pyface.qt import QtCore, QtGui
 from traits.api import Any, Bool, Enum, Float, Int, Property, Trait, TraitError
@@ -15,7 +15,7 @@ def valid_range(object, name, value):
     """ Verify that a set of range values for a scrollbar is valid.
     """
     try:
-        if (type(value) in (TupleType, ListType)) and (len(value) == 4):
+        if (type(value) in (tuple, list)) and (len(value) == 4):
             low, high, page_size, line_size = value
             if high < low:
                 low, high = high, low
@@ -44,7 +44,9 @@ def valid_scroll_position(object, name, value):
 
 
 class QResizableScrollBar(QtGui.QScrollBar):
+
     resized = QtCore.Signal()
+
     def resizeEvent(self, event):
         super(QResizableScrollBar, self).resizeEvent(event)
         self.resized.emit()
@@ -116,6 +118,7 @@ class NativeScrollBar(Component):
         if self._control is not None:
             self._control.hide()
             self._control.deleteLater()
+            self._control = None
         return
 
     def __del__(self):
@@ -127,7 +130,7 @@ class NativeScrollBar(Component):
 
     def _draw_mainlayer(self, gc, view_bounds=None, mode="default"):
         x_pos, y_pos = self.position
-        x_size, y_size = map(int, self.bounds)
+        x_size, y_size = sm.map(int, self.bounds)
 
         qt_xpos, qt_ypos = self._get_abs_coords(x_pos, y_pos+y_size-1)
 
@@ -174,24 +177,51 @@ class NativeScrollBar(Component):
         self._control.sliderPressed.connect(self._on_slider_pressed)
         self._control.sliderReleased.connect(self._on_slider_released)
         self._control.resized.connect(self._control_resized)
+        self._control.destroyed.connect(self._on_destroyed)
         self._control.setVisible(True)
 
     def _update_control(self, enable_range, value):
         minimum, maximum, page_size, line_size = enable_range
-        self._control.setMinimum(minimum)
         # The maximum value of a QScrollBar is the maximum position of the
         # scroll bar, not the document length. We need to subtract the length
         # of the scroll bar itself.
-        self._control.setMaximum(maximum-page_size)
+        max_value = maximum-page_size
+        # invert values for vertical ranges because of coordinate system issues
+        value = self._correct_value(value, minimum, max_value)
+
+        self._control.setMinimum(minimum)
+        self._control.setMaximum(max_value)
         self._control.setValue(value)
         self._control.setPageStep(page_size)
         self._control.setSingleStep(line_size)
 
+    def _correct_value(self, value, min_value, max_value):
+        """ Correct vertical position values for Qt and Enable conventions
+
+        Enable expects vertical scroll_position to be measured with origin at
+        the bottom and positive going upwards, while Qt scrollbar values are
+        measured with origin at the top and positive going down.
+
+        Parameters
+        ----------
+        value : float
+            The position value in either Enable or Qt conventions.
+        max_value : float
+            The maximum value that the Qt scrollbar can be set to (height of
+            the scrolled component, less the page size).
+        """
+        if self.orientation != 'vertical':
+            return value
+        return max_value - (value - min_value)
+
+
     #------------------------------------------------------------------------
     # Qt Event handlers
     #------------------------------------------------------------------------
 
     def _update_enable_pos(self, value):
+        # invert values for vertical ranges because of coordinate system issues
+        value = self._correct_value(value, self.low, self.high-self.page_size)
         self.scroll_position = value
 
     def _on_slider_pressed(self):
@@ -204,6 +234,9 @@ class NativeScrollBar(Component):
         self._widget_moved = True
         self.request_redraw()
 
+    def _on_destroyed(self):
+        self._control = None
+
     #------------------------------------------------------------------------
     # Basic trait event handlers
     #------------------------------------------------------------------------
@@ -285,4 +318,3 @@ class NativeScrollBar(Component):
         low, high, page_size, ignore = self.range
         self._clean = False
         self.range =(low, high, page_size, line_size)
-
