@@ -1,12 +1,12 @@
 """
     Parsers for specific attributes
 """
-import urlparse
+import six.moves.urllib.parse as urlparse
 from pyparsing import (Literal,
     Optional, oneOf, Group, StringEnd, Combine, Word, alphas, hexnums,
     CaselessLiteral, SkipTo
 )
-from css.colour import colourValue
+from .css.colour import colourValue
 import string
 
 ##Paint values
@@ -14,7 +14,12 @@ none = CaselessLiteral("none").setParseAction(lambda t: ["NONE", ()])
 currentColor = CaselessLiteral("currentColor").setParseAction(lambda t: ["CURRENTCOLOR", ()])
 
 def parsePossibleURL(t):
-    possibleURL, fallback = t[0]
+    # Workaround for PyParsing versions < 2.1.0, for which t is wrapped in an
+    # extra level of nesting. See enthought/enable#224.
+    if len(t) == 1:
+        t = t[0]
+
+    possibleURL, fallback = t
     return [urlparse.urlsplit(possibleURL), fallback]
 
 #Normal color declaration
