@@ -1,6 +1,6 @@
 """ CSS at-rules"""
 
 from pyparsing import Literal, Combine
-from identifier import identifier
+from .identifier import identifier
 
 atkeyword = Combine(Literal("@") + identifier)
