@@ -1,4 +1,5 @@
 """ Parse CSS identifiers. More complicated than it sounds"""
+import six
 
 from pyparsing import Word, Literal, Regex, Combine, Optional, White, oneOf, ZeroOrMore
 import string
@@ -16,7 +17,7 @@ escaped = (
 )
 
 def convertToUnicode(t):
-    return unichr(int(t[0], 16))
+    return six.unichr(int(t[0], 16))
 hex_unicode = (
     Literal("\\").suppress() +
     Regex("[0-9a-f]{1,6}", re.IGNORECASE) +
