@@ -1,6 +1,9 @@
 # Copyright (c) 2008-2013 by Enthought, Inc.
 # All rights reserved.
-from mock import Mock
+try:
+    from unittest.mock import Mock
+except ImportError:
+    from mock import Mock
 
 from enable.abstract_window import AbstractWindow
 from enable.events import MouseEvent, KeyEvent, DragEvent
@@ -47,7 +50,9 @@ class EnableTestAssistant(KivaTestAssistant):
         window : AbstractWindow, optional
             The enable AbstractWindow to associate with the event. Default
             is to create a mock class instance. If the window has a mouse
-            owner then that interactor is used.
+            owner then that interactor is used.  If a non-Mocked window is
+            used, then either the test should not require the use of
+            get_pointer_position() or should use a mock for the method.
 
         alt_down : boolean, optional
             The button is pressed while `alt` is down. Default value is False.
@@ -149,6 +154,8 @@ class EnableTestAssistant(KivaTestAssistant):
             'alt_down': False,
             'control_down': False,
             'shift_down': False,
+            'mouse_wheel': 0,
+            'mouse_wheel_axis': 'vertical',
         }
         event_attributes.update(**kwargs)
         event = MouseEvent(**event_attributes)
@@ -231,7 +238,9 @@ class EnableTestAssistant(KivaTestAssistant):
         window : AbstractWindow, optional
             The enable AbstractWindow to associate with the event. Default
             is to create a mock class instance. If the window has a mouse
-            owner then that interactor is used.
+            owner then that interactor is used.  If a non-Mocked window is
+            used, then either the test should not require the use of
+            get_pointer_position() or should use a mock for the method.
 
         alt_down : boolean, optional
             The button is pressed while `alt` is down. Default value is False.
@@ -256,7 +265,9 @@ class EnableTestAssistant(KivaTestAssistant):
                                         alt_down=alt_down,
                                         control_down=control_down,
                                         shift_down=shift_down)
-        window.get_pointer_position.return_value = (x, y)
+        if hasattr(window.get_pointer_position, 'return_value'):
+            # Note: Non-mock windows shouldn't try to get pointer position
+            window.get_pointer_position.return_value = (x, y)
         self._mouse_event_dispatch(interactor, event, 'mouse_move')
         return event
 
