@@ -5,14 +5,16 @@ from __future__ import with_statement
 from math import floor, sqrt
 from bisect import insort_left
 
+import six.moves as sm
+
 # Enthought library imports
 from traits.api import (Bool, Int, Event, Instance, Any, Property,
                                   List, DelegatesTo)
 
 # Local, relative imports
-from component import Component
-from font_metrics_provider import font_metrics_provider
-from text_field_style import TextFieldStyle
+from .component import Component
+from .font_metrics_provider import font_metrics_provider
+from .text_field_style import TextFieldStyle
 
 
 StyleDelegate = DelegatesTo("_style")
@@ -307,7 +309,7 @@ class TextField(Component):
         elif len(event.character) == 1:
             # XXX normal keypress, so let it go through
             return
-            
+
         event.handled = True
         self.invalidate_draw()
         self.request_redraw()
@@ -332,7 +334,7 @@ class TextField(Component):
                 else:
                     y_offset = char_h - self._style.line_spacing
                 y = self.y2 - y_offset - self._style.text_offset
-    
+
                 # Show text at the same scale as the graphics context
                 ctm = gc.get_ctm()
                 if hasattr(ctm, "__len__") and len(ctm) == 6:
@@ -345,7 +347,7 @@ class TextField(Component):
                 x *= scale
                 y *= scale
                 gc.show_text_at_point(line, x, y)
-        
+
             if self._draw_cursor:
                 j, i = self._cursor_pos
                 j -= self._draw_text_ystart
@@ -355,14 +357,14 @@ class TextField(Component):
                 y = self.y2 - y_offset - self._style.text_offset
                 if not self.multiline:
                     char_h -= float(self._style.line_spacing)*.5
-    
+
                 gc.set_line_width(self._style.cursor_width)
                 gc.set_stroke_color(self._style.cursor_color)
                 gc.begin_path()
                 x_position = self.x + x_offset + self._style.text_offset
                 gc.move_to(x_position, y)
                 gc.line_to(x_position, y - char_h)
-    
+
                 gc.stroke_path()
 
 
@@ -390,7 +392,7 @@ class TextField(Component):
         """ Realign all the text being drawn such that the first character being
             drawn in each line is the one at index '_draw_text_xstart.'
         """
-        for i in xrange(len(self.__draw_text)):
+        for i in sm.range(len(self.__draw_text)):
             line = self._text[self._draw_text_ystart + i]
             self.__draw_text[i] = self._clip_line(line, self._draw_text_xstart)
 
@@ -475,7 +477,7 @@ class TextField(Component):
                 self.__draw_text = []
                 self._draw_text_xstart, self._draw_text_ystart = 0, 0
                 end = min(len(self._text), self._text_height)
-                for i in xrange(self._draw_text_ystart, end):
+                for i in sm.range(self._draw_text_ystart, end):
                     line = self._clip_line(self._text[i], 0)
                     self.__draw_text.append(line)
             else:
@@ -555,4 +557,3 @@ class TextField(Component):
         #                   self._style.text_offset*2)
 
         self.request_redraw()
-
