@@ -1,3 +1,6 @@
+# (C) Copyright 2008-2019 Enthought, Inc., Austin, TX
+# All rights reserved.
+
 """
 Tool to detect when the user hovers over a specific part of an underlying
 components.
@@ -7,13 +10,15 @@ from __future__ import absolute_import
 
 # Enthought library imports
 from enable.base_tool import BaseTool
-from traits.etsconfig.api import ETSConfig
-from pyface.toolkit import toolkit_object
 from traits.api import Any, Callable, Enum, Float, Int
+from traits.etsconfig.api import ETSConfig
+from pyface.timer.api import DoLaterTimer
+
 
 # Define a toolkit-specific function for determining the global mouse position
 if ETSConfig.toolkit == 'wx':
     import wx
+
     def GetGlobalMousePosition():
         pos = wx.GetMousePosition()
         if isinstance(pos, tuple):
@@ -25,21 +30,22 @@ if ETSConfig.toolkit == 'wx':
 
 elif ETSConfig.toolkit == 'qt4':
     from pyface.qt import QtGui
+
     def GetGlobalMousePosition():
         pos = QtGui.QCursor.pos()
         return (pos.x(), pos.y())
 
 else:
     def GetGlobalMousePosition():
-        raise NotImplementedError, "GetGlobalMousePosition is not defined for" \
-            "toolkit '%s'." % ETSConfig.toolkit
+        raise NotImplementedError("GetGlobalMousePosition is not defined for"
+                                  "toolkit '%s'." % ETSConfig.toolkit)
 
 
 class HoverTool(BaseTool):
     """
     Tool to detect when the user hovers over a certain area on a component.
-    The type of area to detect can be configured by the 'area_type' and 'bounds'
-    traits.
+    The type of area to detect can be configured by the 'area_type' and
+    'bounds' traits.
 
     Users of the class should either set the 'callback' attribute, or
     subclass and override on_hover().
@@ -70,22 +76,22 @@ class HoverTool(BaseTool):
     # An optional parameter that gets passed to the callback.
     cb_param = Any
 
-    #-------------------------------------------------------------------------
+    # ------------------------------------------------------------------------
     # Private traits
-    #-------------------------------------------------------------------------
+    # ------------------------------------------------------------------------
 
-    # A tuple (x,y) of the mouse position (in global coordinate) when we set the timer
+    # A tuple (x,y) of the mouse position (in global coordinate) when we set
+    # the timer
     _start_xy = Any
 
     # The timer
     _timer = Any
 
-
-    #-------------------------------------------------------------------------
+    # ------------------------------------------------------------------------
     # Public methods
-    #-------------------------------------------------------------------------
+    # ------------------------------------------------------------------------
 
-    def on_hover(self):
+    def on_hover(self, *args, **kwargs):
         """ This gets called when all the conditions of the hover action have
         been met, and the tool determines that the mouse is, in fact, hovering
         over a target region on the component.
@@ -103,17 +109,13 @@ class HoverTool(BaseTool):
             # update xy and restart the timer
             self._start_xy = GetGlobalMousePosition()
             self.restart_hover_timer(event)
-        else:
-            if self._timer:
-                self._timer.Stop()
 
     def restart_hover_timer(self, event):
         if self._timer is None:
             self._create_timer(event)
-        else:
-            self._timer.Start()
+        self._timer.start()
 
-    def on_timer(self):
+    def on_timer(self, *args, **kwargs):
         position = GetGlobalMousePosition()
         diffx = abs(position[0] - self._start_xy[0])
         diffy = abs(position[1] - self._start_xy[1])
@@ -121,15 +123,13 @@ class HoverTool(BaseTool):
         if (diffx < self.hover_threshold) and (diffy < self.hover_threshold):
             self.on_hover()
 
-        self._timer.Stop()
-
-
-    #-------------------------------------------------------------------------
+    # ------------------------------------------------------------------------
     # Private methods
-    #-------------------------------------------------------------------------
+    # ------------------------------------------------------------------------
 
     def _is_in(self, x, y):
-        """ Returns True if local coordinates (x,y) is inside our hover region """
+        """ Returns True if local coordinates (x,y) is inside our hover region
+        """
         area_type = self.area_type.lower()
         c = self.component
 
@@ -137,17 +137,21 @@ class HoverTool(BaseTool):
         b = (y - c.y <= self.area)
         r = (c.x2 - x <= self.area)
         l = (x - c.x <= self.area)
+        corner_mapping = {
+            "ul": t & l,
+            "ur": t & r,
+            "ll": b & l,
+            "lr": b & r,
+        }
 
         if area_type in ("top", "bottom", "left", "right"):
             return locals()[area_type[0]]
-        elif area_type.lower() in ("ul", "ur", "ll", "lr"):
-            u = t
-            return locals()[area_type[0]] and locals()[area_type[1]]
+        elif area_type in ("ul", "ur", "ll", "lr"):
+            return corner_mapping[area_type]
         elif area_type == "corners":
             return (t | b) & (l | r)
         elif area_type == "borders":
             return any((t, b, r, l))
 
     def _create_timer(self, event):
-        klass = toolkit_object("timer.timer:Timer")
-        self._timer = klass(self.hover_delay, self.on_timer)
+        self._timer = DoLaterTimer(self.hover_delay, self.on_timer, (), {})
