@@ -14,7 +14,7 @@
 
 
 # Import the toolkit specific version.
-from toolkit import toolkit_object
+from .toolkit import toolkit_object
 Window = toolkit_object('Window')
 
 #### EOF ######################################################################
