@@ -2,11 +2,10 @@
 This demonstrates the most basic drawing capabilities using Enable.  A new
 component is created and added to a container.
 """
-from __future__ import with_statement
-
 from enable.example_support import DemoFrame, demo_main
 from enable.api import Component, Container, Window
 
+
 class Box(Component):
 
     resizable = ""
@@ -19,14 +18,17 @@ class Box(Component):
             gc.rect(x, y, dx, dy)
             gc.fill_path()
 
+
 class MyFrame(DemoFrame):
+
     def _create_window(self):
         box = Box(bounds=[100.0, 100.0], position=[50.0, 50.0])
-        container = Container(bounds=[500,500])
+        container = Container(bounds=[500, 500])
         container.add(box)
         return Window(self, -1, component=container)
 
-if __name__ == "__main__":
-    demo_main(MyFrame)
 
-# EOF
+if __name__ == "__main__":
+    # Save demo so that it doesn't get garbage collected when run within
+    # existing event loop (i.e. from ipython).
+    demo = demo_main(MyFrame)
