@@ -1,3 +1,5 @@
+from __future__ import print_function
+
 from enable.api import OverlayContainer, Compass, Window
 from enable.example_support import demo_main, DemoFrame
 
@@ -15,7 +17,7 @@ class MyFrame(DemoFrame):
         return Window(self, component=container)
 
     def _arrow_printer(self):
-        print "Clicked:", self.compass.clicked
+        print("Clicked:", self.compass.clicked)
 
 
 if __name__ == "__main__":
