@@ -1,6 +1,8 @@
 """
 Basic demo of drawing within an Enable component.
 """
+from __future__ import print_function
+
 from enable.api import Component, ComponentEditor
 from traits.api import HasTraits, Instance
 from traitsui.api import Item, View
@@ -35,7 +37,7 @@ class MyComponent(Component):
         return
 
     def normal_key_pressed(self, event):
-        print "key pressed: ", event.character
+        print("key pressed: ", event.character)
 
 
 class Demo(HasTraits):
