@@ -9,16 +9,11 @@ and because containers default to auto-sizing around their components,
 the container stretches to the minimum bounding box of its components
 as the user drags the circles around.
 """
-
-from __future__ import with_statement
-
 from numpy import array
 
+from traits.api import Any, Enum, Float, Instance, Tuple
 from enable.example_support import DemoFrame, demo_main
-
-from enable.api import Container, Component, Container, Pointer, str_to_font, Window
-
-from traits.api import Any, Array, Enum, Float, Instance, Trait, Tuple
+from enable.api import Container, Component, Pointer, str_to_font, Window
 
 
 class MyFilledContainer(Container):
@@ -41,8 +36,8 @@ class MyFilledContainer(Container):
             gc.set_font(self._font)
             gc.set_fill_color((1.0, 1.0, 1.0, 1.0))
             tx, ty, tw, th = gc.get_text_extent("Container")
-            tx = self.x + self.width/2.0 - tw/2.0
-            ty = self.y + self.height/2.0 - th/2.0
+            tx = self.x + self.width / 2.0 - tw / 2.0
+            ty = self.y + self.height / 2.0 - th / 2.0
             gc.show_text_at_point("Container", tx, ty)
 
         return
@@ -53,8 +48,7 @@ class Circle(Component):
     The circle moves with the mouse cursor but leaves a translucent version of
     itself in its original position until the mouse button is released.
     """
-
-    color = (0.0, 0.0, 1.0, 1.0)
+    color = (0.6, 0.7, 1.0, 1.0)
     bgcolor = "none"
 
     normal_pointer = Pointer("arrow")
@@ -78,8 +72,8 @@ class Circle(Component):
             gc.set_fill_color(self.color)
             dx, dy = self.bounds
             x, y = self.position
-            radius = min(dx/2.0, dy/2.0)
-            gc.arc(x+dx/2.0, y+dy/2.0, radius, 0.0, 2*3.14159)
+            radius = min(dx / 2.0, dy / 2.0)
+            gc.arc(x + dx / 2.0, y + dy / 2.0, radius, 0.0, 2 * 3.14159)
             gc.fill_path()
         return
 
@@ -132,14 +126,15 @@ class LightCircle(Component):
 
     def _draw_mainlayer(self, gc, view_bounds=None, mode="default"):
         with gc:
-            gc.set_fill_color(self.color[0:3] + (self.color[3]*0.3,))
+            gc.set_fill_color(self.color[0:3] + (self.color[3] * 0.3,))
             dx, dy = self.bounds
             x, y = self.position
-            radius = min(dx/2.0, dy/2.0)
-            gc.arc(x+dx/2.0, y+dy/2.0, radius, 0.0, 2*3.14159)
+            radius = min(dx / 2.0, dy / 2.0)
+            gc.arc(x + dx / 2.0, y + dy / 2.0, radius, 0.0, 2 * 3.14159)
             gc.fill_path()
         return
 
+
 class DashedCircle(Component):
 
     color = Tuple
@@ -153,25 +148,30 @@ class DashedCircle(Component):
             gc.set_fill_color(self.color)
             dx, dy = self.bounds
             x, y = self.position
-            radius = min(dx/2.0, dy/2.0)
-            gc.arc(x+dx/2.0, y+dy/2.0, radius, 0.0, 2*3.14159)
-            gc.set_stroke_color(self.color[0:3] + (self.color[3]*0.8,))
+            radius = min(dx / 2.0, dy / 2.0)
+            gc.arc(x + dx / 2.0, y + dy / 2.0, radius, 0.0, 2 * 3.14159)
+            gc.set_stroke_color(self.color[0:3] + (self.color[3] * 0.8,))
             gc.set_line_dash(self.line_dash)
             gc.stroke_path()
         return
 
 
 class MyFrame(DemoFrame):
+
     def _create_window(self):
-        circle1 = Circle(bounds=[75,75], position=[50, 50], shadow_type="dashed")
-        circle2 = Circle(bounds=[75,75], position=[200, 50], shadow_type="light")
-        container = MyFilledContainer(bounds=[500,500], bgcolor=(0.2, 0.4, 0.3, 1.0))
+        circle1 = Circle(bounds=[75, 75], position=[50, 50],
+                         shadow_type="dashed")
+        circle2 = Circle(bounds=[75, 75], position=[200, 50],
+                         shadow_type="light")
+        container = MyFilledContainer(bounds=[500, 500],
+                                      bgcolor=(0.5, 0.5, 0.5, 1.0))
         container.auto_size = True
         container.add(circle1)
         container.add(circle2)
         return Window(self, -1, component=container)
 
-if __name__ == "__main__":
-    demo_main(MyFrame, title="Click and drag to move the circles")
 
-# EOF
+if __name__ == "__main__":
+    # Save demo so that it doesn't get garbage collected when run within
+    # existing event loop (i.e. from ipython).
+    demo = demo_main(MyFrame, title="Click and drag to move the circles")
