@@ -3,16 +3,18 @@
 from enable.example_support import DemoFrame, demo_main
 from enable.label import Label
 
-from enable.api import Component, Container, Pointer, Window
+from enable.api import Window
+
 
 class MyFrame(DemoFrame):
 
     def _create_window(self):
         label = Label(bounds=[100, 50], position=[50,50], text="HELLO")
-        label.bgcolor = "red"
+        label.bgcolor = "lightpink"
         return Window(self, -1, component=label)
 
-if __name__ == "__main__":
-    demo_main(MyFrame, title="Click and drag to move the box")
 
-# EOF
+if __name__ == "__main__":
+    # Save demo so that it doesn't get garbage collected when run within
+    # existing event loop (i.e. from ipython).
+    demo = demo_main(MyFrame)
