@@ -1,3 +1,5 @@
+from __future__ import print_function
+
 from enable.api import OverlayContainer, Slider, Window
 from enable.example_support import demo_main, DemoFrame
 
@@ -26,7 +28,7 @@ class MyFrame(DemoFrame):
         return Window(self, component=container)
 
     def val_changed(self):
-        print self.slider.value
+        print(self.slider.value)
 
 
 if __name__ == "__main__":
