@@ -1,3 +1,5 @@
+from __future__ import print_function
+
 import time
 import sys
 
@@ -17,7 +19,7 @@ def main():
     t1 = now()
     path_and_color, size, center = get_lion()
     t2 = now()
-    print t2 - t1
+    print(t2 - t1)
 
     gc = agg.GraphicsContextArray(sz)
     t1 = now()
@@ -33,7 +35,7 @@ def main():
             gc.fill_path()
         gc.rotate_ctm(1)
     t2 = now()
-    print 'total time, sec/image, img/sec:', t2 - t1, (t2-t1)/Nimages, Nimages/(t2-t1)
+    print('total time, sec/image, img/sec:', t2 - t1, (t2-t1)/Nimages, Nimages/(t2-t1))
     gc.save('lion.bmp')
 
 if __name__ == "__main__":
