@@ -1,9 +1,9 @@
 # CompiledPath should always be imported from the same backend as the
 # GC you are using.  In this case, we are using the image GraphicsContext
-# so we can save to disk when we're done, so we grab the CompiledPath 
+# so we can save to disk when we're done, so we grab the CompiledPath
 # from there as well.
-from enthought.kiva.backend_image import GraphicsContext, CompiledPath
-from enthought.kiva.constants import STROKE
+from kiva.image import GraphicsContext, CompiledPath
+from kiva.constants import STROKE
 
 star_points = [(-20,-30),
                (0, 30),
