@@ -1,13 +1,13 @@
-from enthought.kiva.backend_image import GraphicsContext
-from enthought.kiva import constants
+from kiva.image import GraphicsContext
+from kiva import constants
 
 def add_star(gc):
     gc.begin_path()
-    
+
     # star
     gc.move_to(-20,-30)
     gc.line_to(0,30)
-    gc.line_to(20,-30)   
+    gc.line_to(20,-30)
     gc.line_to(-30,10)
     gc.line_to(30,10)
     gc.close_path()
