@@ -1,10 +1,8 @@
 import os
 
-from enthought.traits.api import HasTraits
-from enthought.traits.ui.api import View, Item
-from enthought.savage.traits.ui.svg_button import SVGButton
-
-from os.path import dirname, join, abspath
+from traits.api import HasTraits
+from traitsui.api import View, Item
+from enable.savage.trait_defs.ui.svg_button import SVGButton
 
 
 pause_icon = os.path.join(os.path.dirname(__file__), 'player_pause.svg')
