@@ -15,11 +15,13 @@ A multi-platform DisplayPDF vector drawing engine.
 Part of the Enable project of the Enthought Tool Suite.
 """
 
-from constants import *
-from fonttools import Font
+from kiva._version import full_version as __version__
+
+from .constants import *
+from .fonttools import Font
 
 import os
-if os.environ.has_key('KIVA_WISHLIST'):
+if 'KIVA_WISHLIST' in os.environ:
     from warnings import warn
     warn("Use of the KIVA_WISHLIST environment variable to select Kiva backends"
          "is no longer supported.")
