@@ -24,7 +24,7 @@ namespace agg24
     template<class VertexSource> class conv_unclose_polygon
     {
     public:
-        conv_unclose_polygon(VertexSource& vs) : m_source(&vs) {}
+        explicit conv_unclose_polygon(VertexSource& vs) : m_source(&vs) {}
         void attach(VertexSource& source) { m_source = &source; }
 
         void rewind(unsigned path_id)
