@@ -80,12 +80,12 @@ namespace agg24
         double inner_miter_limit() const { return m_inner_miter_limit; }
         double approximation_scale() const { return m_approx_scale; }
 
-        void calc_cap(VertexConsumer& out_vertices,
+        void calc_cap(VertexConsumer& vc,
                       const vertex_dist& v0, 
                       const vertex_dist& v1, 
                       double len);
 
-        void calc_join(VertexConsumer& out_vertices,
+        void calc_join(VertexConsumer& vc,
                        const vertex_dist& v0, 
                        const vertex_dist& v1, 
                        const vertex_dist& v2,
@@ -93,22 +93,29 @@ namespace agg24
                        double len2);
 
     private:
-        void calc_arc(VertexConsumer& out_vertices,
+        AGG_INLINE void add_vertex(VertexConsumer& vc, double x, double y)
+        {
+            vc.add(coord_type(x, y));
+        }
+
+        void calc_arc(VertexConsumer& vc,
                       double x,   double y, 
                       double dx1, double dy1, 
                       double dx2, double dy2);
 
-        void calc_miter(VertexConsumer& out_vertices,
+        void calc_miter(VertexConsumer& vc,
                         const vertex_dist& v0, 
                         const vertex_dist& v1, 
                         const vertex_dist& v2,
                         double dx1, double dy1, 
                         double dx2, double dy2,
                         line_join_e lj,
-                        double ml);
+                        double mlimit,
+                        double dbevel);
 
         double       m_width;
         double       m_width_abs;
+        double       m_width_eps;
         int          m_width_sign;
         double       m_miter_limit;
         double       m_inner_miter_limit;
@@ -122,6 +129,7 @@ namespace agg24
     template<class VC> math_stroke<VC>::math_stroke() :
         m_width(0.5),
         m_width_abs(0.5),
+        m_width_eps(0.5/1024.0),
         m_width_sign(1),
         m_miter_limit(4.0),
         m_inner_miter_limit(1.01),
@@ -146,6 +154,7 @@ namespace agg24
             m_width_abs  = m_width;
             m_width_sign = 1;
         }
+        m_width_eps = m_width / 1024.0;
     }
 
     //-----------------------------------------------------------------------
@@ -156,7 +165,7 @@ namespace agg24
 
     //-----------------------------------------------------------------------
     template<class VC> 
-    void math_stroke<VC>::calc_arc(VC& out_vertices,
+    void math_stroke<VC>::calc_arc(VC& vc,
                                    double x,   double y, 
                                    double dx1, double dy1, 
                                    double dx2, double dy2)
@@ -168,7 +177,7 @@ namespace agg24
 
         da = acos(m_width_abs / (m_width_abs + 0.125 / m_approx_scale)) * 2;
 
-        out_vertices.add(coord_type(x + dx1, y + dy1));
+        add_vertex(vc, x + dx1, y + dy1);
         if(m_width_sign > 0)
         {
             if(a1 > a2) a2 += 2 * pi;
@@ -177,8 +186,7 @@ namespace agg24
             a1 += da;
             for(i = 0; i < n; i++)
             {
-                out_vertices.add(coord_type(x + cos(a1) * m_width, 
-                                            y + sin(a1) * m_width));
+                add_vertex(vc, x + cos(a1) * m_width, y + sin(a1) * m_width);
                 a1 += da;
             }
         }
@@ -190,28 +198,31 @@ namespace agg24
             a1 -= da;
             for(i = 0; i < n; i++)
             {
-                out_vertices.add(coord_type(x + cos(a1) * m_width, 
-                                            y + sin(a1) * m_width));
+                add_vertex(vc, x + cos(a1) * m_width, y + sin(a1) * m_width);
                 a1 -= da;
             }
         }
-        out_vertices.add(coord_type(x + dx2, y + dy2));
+        add_vertex(vc, x + dx2, y + dy2);
     }
 
     //-----------------------------------------------------------------------
     template<class VC> 
-    void math_stroke<VC>::calc_miter(VC& out_vertices,
+    void math_stroke<VC>::calc_miter(VC& vc,
                                      const vertex_dist& v0, 
                                      const vertex_dist& v1, 
                                      const vertex_dist& v2,
                                      double dx1, double dy1, 
                                      double dx2, double dy2,
                                      line_join_e lj,
-                                     double ml)
+                                     double mlimit,
+                                     double dbevel)
     {
-        double xi = v1.x;
-        double yi = v1.y;
+        double xi  = v1.x;
+        double yi  = v1.y;
+        double di  = 1;
+        double lim = m_width_abs * mlimit;
         bool miter_limit_exceeded = true; // Assume the worst
+        bool intersection_failed  = true; // Assume the worst
 
         if(calc_intersection(v0.x + dx1, v0.y - dy1,
                              v1.x + dx1, v1.y - dy1,
@@ -221,15 +232,15 @@ namespace agg24
         {
             // Calculation of the intersection succeeded
             //---------------------
-            double d1 = calc_distance(v1.x, v1.y, xi, yi);
-            double lim = m_width_abs * ml;
-            if(d1 <= lim)
+            di = calc_distance(v1.x, v1.y, xi, yi);
+            if(di <= lim)
             {
                 // Inside the miter limit
                 //---------------------
-                out_vertices.add(coord_type(xi, yi));
+                add_vertex(vc, xi, yi);
                 miter_limit_exceeded = false;
             }
+            intersection_failed = false;
         }
         else
         {
@@ -243,13 +254,13 @@ namespace agg24
             //----------------
             double x2 = v1.x + dx1;
             double y2 = v1.y - dy1;
-            if(((x2 - v0.x)*dy1 - (v0.y - y2)*dx1 < 0.0) !=
-               ((x2 - v2.x)*dy1 - (v2.y - y2)*dx1 < 0.0))
+            if((cross_product(v0.x, v0.y, v1.x, v1.y, x2, y2) < 0.0) ==
+               (cross_product(v1.x, v1.y, v2.x, v2.y, x2, y2) < 0.0))
             {
                 // This case means that the next segment continues 
                 // the previous one (straight line)
                 //-----------------
-                out_vertices.add(coord_type(v1.x + dx1, v1.y - dy1));
+                add_vertex(vc, v1.x + dx1, v1.y - dy1);
                 miter_limit_exceeded = false;
             }
         }
@@ -265,22 +276,37 @@ namespace agg24
                 // we use a simple bevel join instead of
                 // "smart" bevel
                 //-------------------
-                out_vertices.add(coord_type(v1.x + dx1, v1.y - dy1));
-                out_vertices.add(coord_type(v1.x + dx2, v1.y - dy2));
+                add_vertex(vc, v1.x + dx1, v1.y - dy1);
+                add_vertex(vc, v1.x + dx2, v1.y - dy2);
                 break;
 
             case miter_join_round:
-                calc_arc(out_vertices, v1.x, v1.y, dx1, -dy1, dx2, -dy2);
+                calc_arc(vc, v1.x, v1.y, dx1, -dy1, dx2, -dy2);
                 break;
 
             default:
                 // If no miter-revert, calculate new dx1, dy1, dx2, dy2
                 //----------------
-                ml *= m_width_sign;
-                out_vertices.add(coord_type(v1.x + dx1 + dy1 * ml, 
-                                            v1.y - dy1 + dx1 * ml));
-                out_vertices.add(coord_type(v1.x + dx2 - dy2 * ml, 
-                                            v1.y - dy2 - dx2 * ml));
+                if(intersection_failed)
+                {
+                    mlimit *= m_width_sign;
+                    add_vertex(vc, v1.x + dx1 + dy1 * mlimit,
+                                   v1.y - dy1 + dx1 * mlimit);
+                    add_vertex(vc, v1.x + dx2 - dy2 * mlimit,
+                                   v1.y - dy2 - dx2 * mlimit);
+                }
+                else
+                {
+                    double x1 = v1.x + dx1;
+                    double y1 = v1.y - dy1;
+                    double x2 = v1.x + dx2;
+                    double y2 = v1.y - dy2;
+                    di = (lim - dbevel) / (di - dbevel);
+                    add_vertex(vc, x1 + (xi - x1) * di,
+                                   y1 + (yi - y1) * di);
+                    add_vertex(vc, x2 + (xi - x2) * di,
+                                   y2 + (yi - y2) * di);
+                }
                 break;
             }
         }
@@ -288,12 +314,12 @@ namespace agg24
 
     //--------------------------------------------------------stroke_calc_cap
     template<class VC> 
-    void math_stroke<VC>::calc_cap(VC& out_vertices,
+    void math_stroke<VC>::calc_cap(VC& vc,
                                    const vertex_dist& v0, 
                                    const vertex_dist& v1, 
                                    double len)
     {
-        out_vertices.remove_all();
+        vc.remove_all();
 
         double dx1 = (v1.y - v0.y) / len;
         double dy1 = (v1.x - v0.x) / len;
@@ -310,8 +336,8 @@ namespace agg24
                 dx2 = dy1 * m_width_sign;
                 dy2 = dx1 * m_width_sign;
             }
-            out_vertices.add(coord_type(v0.x - dx1 - dx2, v0.y + dy1 - dy2));
-            out_vertices.add(coord_type(v0.x + dx1 - dx2, v0.y - dy1 - dy2));
+            add_vertex(vc, v0.x - dx1 - dx2, v0.y + dy1 - dy2);
+            add_vertex(vc, v0.x + dx1 - dx2, v0.y - dy1 - dy2);
         }
         else
         {
@@ -321,15 +347,15 @@ namespace agg24
             int n = int(pi / da);
 
             da = pi / (n + 1);
-            out_vertices.add(coord_type(v0.x - dx1, v0.y + dy1));
+            add_vertex(vc, v0.x - dx1, v0.y + dy1);
             if(m_width_sign > 0)
             {
                 a1 = atan2(dy1, -dx1);
                 a1 += da;
                 for(i = 0; i < n; i++)
                 {
-                    out_vertices.add(coord_type(v0.x + cos(a1) * m_width, 
-                                                v0.y + sin(a1) * m_width));
+                    add_vertex(vc, v0.x + cos(a1) * m_width,
+                                   v0.y + sin(a1) * m_width);
                     a1 += da;
                 }
             }
@@ -339,81 +365,81 @@ namespace agg24
                 a1 -= da;
                 for(i = 0; i < n; i++)
                 {
-                    out_vertices.add(coord_type(v0.x + cos(a1) * m_width, 
-                                                v0.y + sin(a1) * m_width));
+                    add_vertex(vc, v0.x + cos(a1) * m_width,
+                                   v0.y + sin(a1) * m_width);
                     a1 -= da;
                 }
             }
-            out_vertices.add(coord_type(v0.x + dx1, v0.y - dy1));
+            add_vertex(vc, v0.x + dx1, v0.y - dy1);
         }
     }
 
     //-----------------------------------------------------------------------
     template<class VC> 
-    void math_stroke<VC>::calc_join(VC& out_vertices,
+    void math_stroke<VC>::calc_join(VC& vc,
                                     const vertex_dist& v0, 
                                     const vertex_dist& v1, 
                                     const vertex_dist& v2,
                                     double len1, 
                                     double len2)
     {
-        double dx1, dy1, dx2, dy2;
-        double d;
+        double dx1 = m_width * (v1.y - v0.y) / len1;
+        double dy1 = m_width * (v1.x - v0.x) / len1;
+        double dx2 = m_width * (v2.y - v1.y) / len2;
+        double dy2 = m_width * (v2.x - v1.x) / len2;
 
-        dx1 = m_width * (v1.y - v0.y) / len1;
-        dy1 = m_width * (v1.x - v0.x) / len1;
-
-        dx2 = m_width * (v2.y - v1.y) / len2;
-        dy2 = m_width * (v2.x - v1.x) / len2;
-
-        out_vertices.remove_all();
+        vc.remove_all();
 
         double cp = cross_product(v0.x, v0.y, v1.x, v1.y, v2.x, v2.y);
         if(cp != 0 && (cp > 0) == (m_width > 0))
         {
             // Inner join
             //---------------
+            double limit = ((len1 < len2) ? len1 : len2) / m_width_abs;
+            if(limit < m_inner_miter_limit)
+            {
+                limit = m_inner_miter_limit;
+            }
+
             switch(m_inner_join)
             {
             default: // inner_bevel
-                out_vertices.add(coord_type(v1.x + dx1, v1.y - dy1));
-                out_vertices.add(coord_type(v1.x + dx2, v1.y - dy2));
+                add_vertex(vc, v1.x + dx1, v1.y - dy1);
+                add_vertex(vc, v1.x + dx2, v1.y - dy2);
                 break;
 
             case inner_miter:
-                calc_miter(out_vertices,
+                calc_miter(vc,
                            v0, v1, v2, dx1, dy1, dx2, dy2, 
                            miter_join_revert, 
-                           m_inner_miter_limit);
+                           limit, 0);
                 break;
 
             case inner_jag:
             case inner_round:
+                cp = (dx1-dx2) * (dx1-dx2) + (dy1-dy2) * (dy1-dy2);
+                if(cp < len1 * len1 && cp < len2 * len2)
                 {
-                    d = (dx1-dx2) * (dx1-dx2) + (dy1-dy2) * (dy1-dy2);
-                    if(d < len1 * len1 && d < len2 * len2)
+                    calc_miter(vc,
+                               v0, v1, v2, dx1, dy1, dx2, dy2,
+                               miter_join_revert,
+                               limit, 0);
+                }
+                else
+                {
+                    if(m_inner_join == inner_jag)
                     {
-                        calc_miter(out_vertices,
-                                   v0, v1, v2, dx1, dy1, dx2, dy2, 
-                                   miter_join_revert, 
-                                   m_inner_miter_limit);
+                        add_vertex(vc, v1.x + dx1, v1.y - dy1);
+                        add_vertex(vc, v1.x,       v1.y      );
+                        add_vertex(vc, v1.x + dx2, v1.y - dy2);
                     }
                     else
                     {
-                        if(m_inner_join == inner_jag)
-                        {
-                            out_vertices.add(coord_type(v1.x + dx1, v1.y - dy1));
-                            out_vertices.add(coord_type(v1.x,       v1.y      ));
-                            out_vertices.add(coord_type(v1.x + dx2, v1.y - dy2));
-                        }
-                        else
-                        {
-                            out_vertices.add(coord_type(v1.x + dx1, v1.y - dy1));
-                            out_vertices.add(coord_type(v1.x,       v1.y      ));
-                            calc_arc(out_vertices, v1.x, v1.y, dx2, -dy2, dx1, -dy1);
-                            out_vertices.add(coord_type(v1.x,       v1.y      ));
-                            out_vertices.add(coord_type(v1.x + dx2, v1.y - dy2));
-                        }
+                        add_vertex(vc, v1.x + dx1, v1.y - dy1);
+                        add_vertex(vc, v1.x,       v1.y      );
+                        calc_arc(vc, v1.x, v1.y, dx2, -dy2, dx1, -dy1);
+                        add_vertex(vc, v1.x,       v1.y      );
+                        add_vertex(vc, v1.x + dx2, v1.y - dy2);
                     }
                 }
                 break;
@@ -423,11 +449,18 @@ namespace agg24
         {
             // Outer join
             //---------------
-            line_join_e lj = m_line_join;
+
+            // Calculate the distance between v1 and
+            // the central point of the bevel line segment
+            //---------------
+            double dx = (dx1 + dx2) / 2;
+            double dy = (dy1 + dy2) / 2;
+            double dbevel = sqrt(dx * dx + dy * dy);
+
             if(m_line_join == round_join || m_line_join == bevel_join)
             {
                 // This is an optimization that reduces the number of points 
-                // in cases of almost collonear segments. If there's no
+                // in cases of almost collinear segments. If there's no
                 // visible difference between bevel and miter joins we'd rather
                 // use miter join because it adds only one point instead of two. 
                 //
@@ -436,40 +469,50 @@ namespace agg24
                 // At outer joins this distance always less than stroke width, 
                 // because it's actually the height of an isosceles triangle of
                 // v1 and its two bevel points. If the difference between this
-                // width and this value is small (no visible bevel) we can switch
-                // to the miter join. 
+                // width and this value is small (no visible bevel) we can
+                // add just one point.
                 //
                 // The constant in the expression makes the result approximately 
-                // the same as in round joins and caps. One can safely comment 
-                // out this "if".
+                // the same as in round joins and caps. You can safely comment
+                // out this entire "if".
                 //-------------------
-                double dx = (dx1 + dx2) / 2;
-                double dy = (dy1 + dy2) / 2;
-                d = m_width_abs - sqrt(dx * dx + dy * dy);
-                if(d < 0.0625 / m_approx_scale)
+                if(m_approx_scale * (m_width_abs - dbevel) < m_width_eps)
                 {
-                    lj = miter_join;
+                    if(calc_intersection(v0.x + dx1, v0.y - dy1,
+                                         v1.x + dx1, v1.y - dy1,
+                                         v1.x + dx2, v1.y - dy2,
+                                         v2.x + dx2, v2.y - dy2,
+                                         &dx, &dy))
+                    {
+                        add_vertex(vc, dx, dy);
+                    }
+                    else
+                    {
+                        add_vertex(vc, v1.x + dx1, v1.y - dy1);
+                    }
+                    return;
                 }
             }
 
-            switch(lj)
+            switch(m_line_join)
             {
             case miter_join:
             case miter_join_revert:
             case miter_join_round:
-                calc_miter(out_vertices, 
+                calc_miter(vc,
                            v0, v1, v2, dx1, dy1, dx2, dy2, 
-                           lj, 
-                           m_miter_limit);
+                           m_line_join,
+                           m_miter_limit,
+                           dbevel);
                 break;
 
             case round_join:
-                calc_arc(out_vertices, v1.x, v1.y, dx1, -dy1, dx2, -dy2);
+                calc_arc(vc, v1.x, v1.y, dx1, -dy1, dx2, -dy2);
                 break;
 
             default: // Bevel join
-                out_vertices.add(coord_type(v1.x + dx1, v1.y - dy1));
-                out_vertices.add(coord_type(v1.x + dx2, v1.y - dy2));
+                add_vertex(vc, v1.x + dx1, v1.y - dy1);
+                add_vertex(vc, v1.x + dx2, v1.y - dy2);
                 break;
             }
         }
