@@ -37,7 +37,7 @@ namespace agg24
         typedef renderer_base<pixfmt_type> base_ren_type;
 
         //--------------------------------------------------------------------
-        renderer_mclip(pixfmt_type& pixf) :
+        explicit renderer_mclip(pixfmt_type& pixf) :
             m_ren(pixf),
             m_curr_cb(0),
             m_bounds(m_ren.xmin(), m_ren.ymin(), m_ren.xmax(), m_ren.ymax())
