@@ -62,7 +62,7 @@ namespace agg24
     //
     // scanline_u8::const_iterator span = sl.begin();
     // 
-    // unsigned char* row = m_rbuf->row(y); // The the address of the beginning 
+    // unsigned char* row = m_rbuf->row(y); // The address of the beginning
     //                                      // of the current row
     // 
     // unsigned num_spans = sl.num_spans(); // Number of spans. It's guaranteed that
@@ -252,7 +252,7 @@ namespace agg24
         typedef base_type::coord_type coord_type;
 
         scanline_u8_am() : base_type(), m_alpha_mask(0) {}
-        scanline_u8_am(const AlphaMask& am) : base_type(), m_alpha_mask(&am) {}
+        scanline_u8_am(AlphaMask& am) : base_type(), m_alpha_mask(&am) {}
 
         //--------------------------------------------------------------------
         void finalize(int span_y)
@@ -275,7 +275,7 @@ namespace agg24
         }
 
     private:
-        const AlphaMask* m_alpha_mask;
+        AlphaMask* m_alpha_mask;
     };
 
 
@@ -458,14 +458,14 @@ namespace agg24
     class scanline32_u8_am : public scanline32_u8
     {
     public:
-        typedef scanline32_u8           base_type;
+        typedef scanline32_u8         base_type;
         typedef AlphaMask             alpha_mask_type;
         typedef base_type::cover_type cover_type;
         typedef base_type::coord_type coord_type;
 
 
         scanline32_u8_am() : base_type(), m_alpha_mask(0) {}
-        scanline32_u8_am(const AlphaMask& am) : base_type(), m_alpha_mask(&am) {}
+        scanline32_u8_am(AlphaMask& am) : base_type(), m_alpha_mask(&am) {}
 
         //--------------------------------------------------------------------
         void finalize(int span_y)
@@ -488,7 +488,7 @@ namespace agg24
         }
 
     private:
-        const AlphaMask* m_alpha_mask;
+        AlphaMask* m_alpha_mask;
     };
 
 
