@@ -43,11 +43,7 @@ namespace agg24
         typedef span_image_filter<source_type, interpolator_type> base_type;
         typedef typename color_type::value_type value_type;
         typedef typename color_type::calc_type calc_type;
-        enum base_scale_e
-        {
-            base_shift = color_type::base_shift,
-            base_mask  = color_type::base_mask
-        };
+        typedef typename color_type::long_type long_type;
 
         //--------------------------------------------------------------------
         span_image_filter_gray_nn() {}
@@ -68,7 +64,7 @@ namespace agg24
                     base_type::source().span(x >> image_subpixel_shift, 
                                              y >> image_subpixel_shift, 
                                              1);
-                span->a = base_mask;
+                span->a = color_type::full_value();
                 ++span;
                 ++base_type::interpolator();
             } while(--len);
@@ -89,11 +85,7 @@ namespace agg24
         typedef span_image_filter<source_type, interpolator_type> base_type;
         typedef typename color_type::value_type value_type;
         typedef typename color_type::calc_type calc_type;
-        enum base_scale_e
-        {
-            base_shift = color_type::base_shift,
-            base_mask  = color_type::base_mask
-        };
+        typedef typename color_type::long_type long_type;
 
         //--------------------------------------------------------------------
         span_image_filter_gray_bilinear() {}
@@ -108,7 +100,7 @@ namespace agg24
         {
             base_type::interpolator().begin(x + base_type::filter_dx_dbl(), 
                                             y + base_type::filter_dy_dbl(), len);
-            calc_type fg;
+            long_type fg;
             const value_type *fg_ptr;
             do
             {
@@ -123,7 +115,7 @@ namespace agg24
                 int x_lr = x_hr >> image_subpixel_shift;
                 int y_lr = y_hr >> image_subpixel_shift;
 
-                fg = image_subpixel_scale * image_subpixel_scale / 2;
+                fg = 0;
 
                 x_hr &= image_subpixel_mask;
                 y_hr &= image_subpixel_mask;
@@ -140,8 +132,8 @@ namespace agg24
                 fg_ptr = (const value_type*)base_type::source().next_x();
                 fg    += *fg_ptr * x_hr * y_hr;
 
-                span->v = value_type(fg >> (image_subpixel_shift * 2));
-                span->a = base_mask;
+                span->v = color_type::downshift(fg, image_subpixel_shift * 2);
+                span->a = color_type::full_value();
                 ++span;
                 ++base_type::interpolator();
 
@@ -162,11 +154,7 @@ namespace agg24
         typedef span_image_filter<source_type, interpolator_type> base_type;
         typedef typename color_type::value_type value_type;
         typedef typename color_type::calc_type calc_type;
-        enum base_scale_e
-        {
-            base_shift = color_type::base_shift,
-            base_mask  = color_type::base_mask
-        };
+        typedef typename color_type::long_type long_type;
 
         //--------------------------------------------------------------------
         span_image_filter_gray_bilinear_clip() {}
@@ -184,8 +172,8 @@ namespace agg24
         {
             base_type::interpolator().begin(x + base_type::filter_dx_dbl(), 
                                             y + base_type::filter_dy_dbl(), len);
-            calc_type fg;
-            calc_type src_alpha;
+            long_type fg;
+            long_type src_alpha;
             value_type back_v = m_back_color.v;
             value_type back_a = m_back_color.a;
 
@@ -210,7 +198,7 @@ namespace agg24
                 if(x_lr >= 0    && y_lr >= 0 &&
                    x_lr <  maxx && y_lr <  maxy) 
                 {
-                    fg = image_subpixel_scale * image_subpixel_scale / 2;
+                    fg = 0;
 
                     x_hr &= image_subpixel_mask;
                     y_hr &= image_subpixel_mask;
@@ -225,8 +213,8 @@ namespace agg24
                     fg += *fg_ptr++ * (image_subpixel_scale - x_hr) * y_hr;
                     fg += *fg_ptr++ * x_hr * y_hr;
 
-                    fg >>= image_subpixel_shift * 2;
-                    src_alpha = base_mask;
+                    fg = color_type::downshift(fg, image_subpixel_shift * 2);
+                    src_alpha = color_type::full_value();
                 }
                 else
                 {
@@ -239,8 +227,7 @@ namespace agg24
                     }
                     else
                     {
-                        fg = 
-                        src_alpha = image_subpixel_scale * image_subpixel_scale / 2;
+                        fg = src_alpha = 0;
 
                         x_hr &= image_subpixel_mask;
                         y_hr &= image_subpixel_mask;
@@ -252,7 +239,7 @@ namespace agg24
                         {
                             fg += weight * 
                                 *((const value_type*)base_type::source().row_ptr(y_lr) + x_lr);
-                            src_alpha += weight * base_mask;
+                            src_alpha += weight * color_type::full_value();
                         }
                         else
                         {
@@ -268,7 +255,7 @@ namespace agg24
                         {
                             fg += weight * 
                                 *((const value_type*)base_type::source().row_ptr(y_lr) + x_lr);
-                            src_alpha += weight * base_mask;
+                            src_alpha += weight * color_type::full_value();
                         }
                         else
                         {
@@ -285,7 +272,7 @@ namespace agg24
                         {
                             fg += weight * 
                                 *((const value_type*)base_type::source().row_ptr(y_lr) + x_lr);
-                            src_alpha += weight * base_mask;
+                            src_alpha += weight * color_type::full_value();
                         }
                         else
                         {
@@ -301,7 +288,7 @@ namespace agg24
                         {
                             fg += weight * 
                                 *((const value_type*)base_type::source().row_ptr(y_lr) + x_lr);
-                            src_alpha += weight * base_mask;
+                            src_alpha += weight * color_type::full_value();
                         }
                         else
                         {
@@ -309,8 +296,8 @@ namespace agg24
                             src_alpha += back_a * weight;
                         }
 
-                        fg        >>= image_subpixel_shift * 2;
-                        src_alpha >>= image_subpixel_shift * 2;
+                        fg = color_type::downshift(fg, image_subpixel_shift * 2);
+                        src_alpha = color_type::downshift(src_alpha, image_subpixel_shift * 2);
                     }
                 }
 
@@ -339,17 +326,13 @@ namespace agg24
         typedef span_image_filter<source_type, interpolator_type> base_type;
         typedef typename color_type::value_type value_type;
         typedef typename color_type::calc_type calc_type;
-        enum base_scale_e
-        {
-            base_shift = color_type::base_shift,
-            base_mask  = color_type::base_mask
-        };
+        typedef typename color_type::long_type long_type;
 
         //--------------------------------------------------------------------
         span_image_filter_gray_2x2() {}
         span_image_filter_gray_2x2(source_type& src, 
                                    interpolator_type& inter,
-                                   const image_filter_lut& filter) :
+                                   image_filter_lut& filter) :
             base_type(src, inter, &filter) 
         {}
 
@@ -360,7 +343,7 @@ namespace agg24
             base_type::interpolator().begin(x + base_type::filter_dx_dbl(), 
                                             y + base_type::filter_dy_dbl(), len);
 
-            calc_type fg;
+            long_type fg;
 
             const value_type *fg_ptr;
             const int16* weight_array = base_type::filter().weight_array() + 
@@ -380,7 +363,7 @@ namespace agg24
                 int y_lr = y_hr >> image_subpixel_shift;
 
                 unsigned weight;
-                fg = image_filter_scale / 2;
+                fg = 0;
 
                 x_hr &= image_subpixel_mask;
                 y_hr &= image_subpixel_mask;
@@ -414,10 +397,10 @@ namespace agg24
                 fg += weight * *fg_ptr;
 
                 fg >>= image_filter_shift;
-                if(fg > base_mask) fg = base_mask;
+                if(fg > color_type::full_value()) fg = color_type::full_value();
 
                 span->v = (value_type)fg;
-                span->a = base_mask;
+                span->a = color_type::full_value();
                 ++span;
                 ++base_type::interpolator();
             } while(--len);
@@ -438,17 +421,13 @@ namespace agg24
         typedef span_image_filter<source_type, interpolator_type> base_type;
         typedef typename color_type::value_type value_type;
         typedef typename color_type::calc_type calc_type;
-        enum base_scale_e
-        {
-            base_shift = color_type::base_shift,
-            base_mask  = color_type::base_mask
-        };
+        typedef typename color_type::long_type long_type;
 
         //--------------------------------------------------------------------
         span_image_filter_gray() {}
         span_image_filter_gray(source_type& src, 
                                interpolator_type& inter,
-                               const image_filter_lut& filter) :
+                               image_filter_lut& filter) :
             base_type(src, inter, &filter) 
         {}
 
@@ -458,7 +437,7 @@ namespace agg24
             base_type::interpolator().begin(x + base_type::filter_dx_dbl(), 
                                             y + base_type::filter_dy_dbl(), len);
 
-            int fg;
+            long_type fg;
             const value_type *fg_ptr;
 
             unsigned     diameter     = base_type::filter().diameter();
@@ -481,7 +460,7 @@ namespace agg24
                 int x_lr = x_hr >> image_subpixel_shift;
                 int y_lr = y_hr >> image_subpixel_shift;
 
-                fg = image_filter_scale / 2;
+                fg = 0;
 
                 int x_fract = x_hr & image_subpixel_mask;
                 unsigned y_count = diameter;
@@ -511,11 +490,11 @@ namespace agg24
                     fg_ptr = (const value_type*)base_type::source().next_y();
                 }
 
-                fg >>= image_filter_shift;
+                fg = color_type::downshift(fg, image_filter_shift);
                 if(fg < 0) fg = 0;
-                if(fg > base_mask) fg = base_mask;
+                if(fg > color_type::full_value()) fg = color_type::full_value();
                 span->v = (value_type)fg;
-                span->a = base_mask;
+                span->a = color_type::full_value();
 
                 ++span;
                 ++base_type::interpolator();
@@ -540,8 +519,6 @@ namespace agg24
         typedef typename color_type::long_type long_type;
         enum base_scale_e
         {
-            base_shift      = color_type::base_shift,
-            base_mask       = color_type::base_mask,
             downscale_shift = image_filter_shift
         };
 
@@ -549,7 +526,7 @@ namespace agg24
         span_image_resample_gray_affine() {}
         span_image_resample_gray_affine(source_type& src, 
                                         interpolator_type& inter,
-                                        const image_filter_lut& filter) :
+                                        image_filter_lut& filter) :
             base_type(src, inter, filter) 
         {}
 
@@ -579,7 +556,7 @@ namespace agg24
                 x += base_type::filter_dx_int() - radius_x;
                 y += base_type::filter_dy_int() - radius_y;
 
-                fg = image_filter_scale / 2;
+                fg = 0;
 
                 int y_lr = y >> image_subpixel_shift;
                 int y_hr = ((image_subpixel_mask - (y & image_subpixel_mask)) * 
@@ -617,10 +594,10 @@ namespace agg24
 
                 fg /= total_weight;
                 if(fg < 0) fg = 0;
-                if(fg > base_mask) fg = base_mask;
+                if(fg > color_type::full_value()) fg = color_type::full_value();
 
                 span->v = (value_type)fg;
-                span->a = base_mask;
+                span->a = color_type::full_value();
 
                 ++span;
                 ++base_type::interpolator();
@@ -644,8 +621,6 @@ namespace agg24
         typedef typename color_type::long_type long_type;
         enum base_scale_e
         {
-            base_shift = color_type::base_shift,
-            base_mask  = color_type::base_mask,
             downscale_shift = image_filter_shift
         };
 
@@ -653,7 +628,7 @@ namespace agg24
         span_image_resample_gray() {}
         span_image_resample_gray(source_type& src, 
                                  interpolator_type& inter,
-                                 const image_filter_lut& filter) :
+                                 image_filter_lut& filter) :
             base_type(src, inter, filter)
         {}
 
@@ -676,35 +651,10 @@ namespace agg24
                 int ry_inv = image_subpixel_scale;
                 base_type::interpolator().coordinates(&x,  &y);
                 base_type::interpolator().local_scale(&rx, &ry);
+                base_type::adjust_scale(&rx, &ry);
 
-                rx = (rx * base_type::m_blur_x) >> image_subpixel_shift;
-                ry = (ry * base_type::m_blur_y) >> image_subpixel_shift;
-
-                if(rx < image_subpixel_scale)
-                {
-                    rx = image_subpixel_scale;
-                }
-                else
-                {
-                    if(rx > image_subpixel_scale * base_type::m_scale_limit) 
-                    {
-                        rx = image_subpixel_scale * base_type::m_scale_limit;
-                    }
-                    rx_inv = image_subpixel_scale * image_subpixel_scale / rx;
-                }
-
-                if(ry < image_subpixel_scale)
-                {
-                    ry = image_subpixel_scale;
-                }
-                else
-                {
-                    if(ry > image_subpixel_scale * base_type::m_scale_limit) 
-                    {
-                        ry = image_subpixel_scale * base_type::m_scale_limit;
-                    }
-                    ry_inv = image_subpixel_scale * image_subpixel_scale / ry;
-                }
+                rx_inv = image_subpixel_scale * image_subpixel_scale / rx;
+                ry_inv = image_subpixel_scale * image_subpixel_scale / ry;
 
                 int radius_x = (diameter * rx) >> 1;
                 int radius_y = (diameter * ry) >> 1;
@@ -715,7 +665,7 @@ namespace agg24
                 x += base_type::filter_dx_int() - radius_x;
                 y += base_type::filter_dy_int() - radius_y;
 
-                fg = image_filter_scale / 2;
+                fg = 0;
 
                 int y_lr = y >> image_subpixel_shift;
                 int y_hr = ((image_subpixel_mask - (y & image_subpixel_mask)) * 
@@ -752,10 +702,10 @@ namespace agg24
 
                 fg /= total_weight;
                 if(fg < 0) fg = 0;
-                if(fg > base_mask) fg = base_mask;
+                if(fg > color_type::full_value()) fg = color_type::full_value();
 
                 span->v = (value_type)fg;
-                span->a = base_mask;
+                span->a = color_type::full_value();
 
                 ++span;
                 ++base_type::interpolator();
