@@ -18,7 +18,7 @@
 // It's not a part of the AGG library, it's just a helper class to create 
 // interactive demo examples. Since the examples should not be too complex
 // this class is provided to support some very basic interactive graphical
-// funtionality, such as putting the rendered image to the window, simple 
+// functionality, such as putting the rendered image to the window, simple
 // keyboard and mouse input, window resizing, setting the window title,
 // and catching the "idle" events.
 // 
@@ -105,7 +105,9 @@ namespace agg24
         pix_format_undefined = 0,  // By default. No conversions are applied 
         pix_format_bw,             // 1 bit per color B/W
         pix_format_gray8,          // Simple 256 level grayscale
+        pix_format_sgray8,         // Simple 256 level grayscale (sRGB)
         pix_format_gray16,         // Simple 65535 level grayscale
+        pix_format_gray32,         // Grayscale, one 32-bit float per pixel
         pix_format_rgb555,         // 15 bit rgb. Depends on the byte ordering!
         pix_format_rgb565,         // 16 bit rgb. Depends on the byte ordering!
         pix_format_rgbAAA,         // 30 bit rgb. Depends on the byte ordering!
@@ -113,18 +115,30 @@ namespace agg24
         pix_format_bgrAAA,         // 30 bit bgr. Depends on the byte ordering!
         pix_format_bgrABB,         // 32 bit bgr. Depends on the byte ordering!
         pix_format_rgb24,          // R-G-B, one byte per color component
-        pix_format_bgr24,          // B-G-R, native win32 BMP format.
+        pix_format_srgb24,         // R-G-B, one byte per color component (sRGB)
+        pix_format_bgr24,          // B-G-R, one byte per color component
+        pix_format_sbgr24,         // B-G-R, native win32 BMP format (sRGB)
         pix_format_rgba32,         // R-G-B-A, one byte per color component
+        pix_format_srgba32,        // R-G-B-A, one byte per color component (sRGB)
         pix_format_argb32,         // A-R-G-B, native MAC format
+        pix_format_sargb32,        // A-R-G-B, native MAC format (sRGB)
         pix_format_abgr32,         // A-B-G-R, one byte per color component
+        pix_format_sabgr32,        // A-B-G-R, one byte per color component (sRGB)
         pix_format_bgra32,         // B-G-R-A, native win32 BMP format
+        pix_format_sbgra32,        // B-G-R-A, native win32 BMP format (sRGB)
         pix_format_rgb48,          // R-G-B, 16 bits per color component
         pix_format_bgr48,          // B-G-R, native win32 BMP format.
+        pix_format_rgb96,          // R-G-B, one 32-bit float per color component
+        pix_format_bgr96,          // B-G-R, one 32-bit float per color component
         pix_format_rgba64,         // R-G-B-A, 16 bits byte per color component
         pix_format_argb64,         // A-R-G-B, native MAC format
         pix_format_abgr64,         // A-B-G-R, one byte per color component
         pix_format_bgra64,         // B-G-R-A, native win32 BMP format
-  
+        pix_format_rgba128,        // R-G-B-A, one 32-bit float per color component
+        pix_format_argb128,        // A-R-G-B, one 32-bit float per color component
+        pix_format_abgr128,        // A-B-G-R, one 32-bit float per color component
+        pix_format_bgra128,        // B-G-R-A, one 32-bit float per color component
+
         end_of_pix_formats
     };
 
@@ -592,6 +606,7 @@ namespace agg24
                     double(height) / double(m_initial_height));
             }
         }
+        trans_affine& trans_affine_resizing() { return m_resize_mtx; }
         const    trans_affine& trans_affine_resizing() const { return m_resize_mtx; }
         double   width()  const { return m_rbuf_window.width(); }
         double   height() const { return m_rbuf_window.height(); }
@@ -629,7 +644,7 @@ namespace agg24
         // open it in the current directory. The demos usually expect 
         // all the supplementary files to be placed in the current 
         // directory, that is usually coincides with the directory where
-        // the the executable is. However, in some systems (BeOS) it's not so. 
+        // the executable is. However, in some systems (BeOS) it's not so.
         // For those kinds of systems full_file_name() can help access files 
         // preserving commonly used policy.
         // So, it's a good idea to use in the demos the following:
