@@ -82,9 +82,6 @@ namespace agg24
         m_step = m_num_steps;
     }
 
-
-
-
     //------------------------------------------------------------------------
     void curve3_inc::rewind(unsigned)
     {
@@ -100,9 +97,6 @@ namespace agg24
         m_dfy  = m_saved_dfy;
     }
 
-
-
-
     //------------------------------------------------------------------------
     unsigned curve3_inc::vertex(double* x, double* y)
     {
@@ -131,7 +125,6 @@ namespace agg24
         return path_cmd_line_to;
     }
 
-
     //------------------------------------------------------------------------
     void curve3_div::init(double x1, double y1, 
                           double x2, double y2, 
@@ -140,12 +133,10 @@ namespace agg24
         m_points.remove_all();
         m_distance_tolerance_square = 0.5 / m_approximation_scale;
         m_distance_tolerance_square *= m_distance_tolerance_square;
-        m_distance_tolerance_manhattan = 4.0 / m_approximation_scale;
         bezier(x1, y1, x2, y2, x3, y3);
         m_count = 0;
     }
 
-
     //------------------------------------------------------------------------
     void curve3_div::recursive_bezier(double x1, double y1, 
                                       double x2, double y2, 
@@ -169,10 +160,11 @@ namespace agg24
         double dx = x3-x1;
         double dy = y3-y1;
         double d = fabs(((x2 - x3) * dy - (y2 - y3) * dx));
+        double da;
 
         if(d > curve_collinearity_epsilon)
         { 
-            // Regular care
+            // Regular case
             //-----------------
             if(d * d <= m_distance_tolerance_square * (dx*dx + dy*dy))
             {
@@ -187,7 +179,7 @@ namespace agg24
 
                 // Angle & Cusp Condition
                 //----------------------
-                double da = fabs(atan2(y3 - y2, x3 - x2) - atan2(y2 - y1, x2 - x1));
+                da = fabs(atan2(y3 - y2, x3 - x2) - atan2(y2 - y1, x2 - x1));
                 if(da >= pi) da = 2*pi - da;
 
                 if(da < m_angle_tolerance)
@@ -201,12 +193,31 @@ namespace agg24
         }
         else
         {
-            if(fabs(x1 + x3 - x2 - x2) +
-               fabs(y1 + y3 - y2 - y2) <= m_distance_tolerance_manhattan)
+            // Collinear case
+            //------------------
+            da = dx*dx + dy*dy;
+            if(da == 0)
             {
-                m_points.add(point_d(x123, y123));
+                d = calc_sq_distance(x1, y1, x2, y2);
+            }
+            else
+            {
+                d = ((x2 - x1)*dx + (y2 - y1)*dy) / da;
+                if(d > 0 && d < 1)
+                {
+                    // Simple collinear case, 1---2---3
+                    // We can leave just two endpoints
+                    return;
+                }
+                     if(d <= 0) d = calc_sq_distance(x2, y2, x1, y1);
+                else if(d >= 1) d = calc_sq_distance(x2, y2, x3, y3);
+                else            d = calc_sq_distance(x2, y2, x1 + d*dx, y1 + d*dy);
+            }
+            if(d < m_distance_tolerance_square)
+            {
+                m_points.add(point_d(x2, y2));
                 return;
-            }    
+            }
         }
 
         // Continue subdivision
@@ -241,8 +252,10 @@ namespace agg24
         return m_scale;
     }
 
+#if defined(_MSC_VER) && _MSC_VER <= 1200
     //------------------------------------------------------------------------
     static double MSC60_fix_ICE(double v) { return v; }
+#endif
 
     //------------------------------------------------------------------------
     void curve4_inc::init(double x1, double y1, 
@@ -307,9 +320,6 @@ namespace agg24
         m_step = m_num_steps;
     }
 
-
-
-
     //------------------------------------------------------------------------
     void curve4_inc::rewind(unsigned)
     {
@@ -327,10 +337,6 @@ namespace agg24
         m_ddfy = m_saved_ddfy;
     }
 
-
-
-
-
     //------------------------------------------------------------------------
     unsigned curve4_inc::vertex(double* x, double* y)
     {
@@ -376,12 +382,10 @@ namespace agg24
         m_points.remove_all();
         m_distance_tolerance_square = 0.5 / m_approximation_scale;
         m_distance_tolerance_square *= m_distance_tolerance_square;
-        m_distance_tolerance_manhattan = 4.0 / m_approximation_scale;
         bezier(x1, y1, x2, y2, x3, y3, x4, y4);
         m_count = 0;
     }
 
-
     //------------------------------------------------------------------------
     void curve4_div::recursive_bezier(double x1, double y1, 
                                       double x2, double y2, 
@@ -409,6 +413,7 @@ namespace agg24
         double x1234 = (x123 + x234) / 2;
         double y1234 = (y123 + y234) / 2;
 
+
         // Try to approximate the full cubic curve by a single straight line
         //------------------
         double dx = x4-x1;
@@ -416,7 +421,7 @@ namespace agg24
 
         double d2 = fabs(((x2 - x4) * dy - (y2 - y4) * dx));
         double d3 = fabs(((x3 - x4) * dy - (y3 - y4) * dx));
-        double da1, da2;
+        double da1, da2, k;
 
         switch((int(d2 > curve_collinearity_epsilon) << 1) +
                 int(d3 > curve_collinearity_epsilon))
@@ -424,18 +429,55 @@ namespace agg24
         case 0:
             // All collinear OR p1==p4
             //----------------------
-            if(fabs(x1 + x3 - x2 - x2) +
-               fabs(y1 + y3 - y2 - y2) +
-               fabs(x2 + x4 - x3 - x3) +
-               fabs(y2 + y4 - y3 - y3) <= m_distance_tolerance_manhattan)
+            k = dx*dx + dy*dy;
+            if(k == 0)
             {
-                m_points.add(point_d(x1234, y1234));
-                return;
-            }    
+                d2 = calc_sq_distance(x1, y1, x2, y2);
+                d3 = calc_sq_distance(x4, y4, x3, y3);
+            }
+            else
+            {
+                k   = 1 / k;
+                da1 = x2 - x1;
+                da2 = y2 - y1;
+                d2  = k * (da1*dx + da2*dy);
+                da1 = x3 - x1;
+                da2 = y3 - y1;
+                d3  = k * (da1*dx + da2*dy);
+                if(d2 > 0 && d2 < 1 && d3 > 0 && d3 < 1)
+                {
+                    // Simple collinear case, 1---2---3---4
+                    // We can leave just two endpoints
+                    return;
+                }
+                     if(d2 <= 0) d2 = calc_sq_distance(x2, y2, x1, y1);
+                else if(d2 >= 1) d2 = calc_sq_distance(x2, y2, x4, y4);
+                else             d2 = calc_sq_distance(x2, y2, x1 + d2*dx, y1 + d2*dy);
+
+                     if(d3 <= 0) d3 = calc_sq_distance(x3, y3, x1, y1);
+                else if(d3 >= 1) d3 = calc_sq_distance(x3, y3, x4, y4);
+                else             d3 = calc_sq_distance(x3, y3, x1 + d3*dx, y1 + d3*dy);
+            }
+            if(d2 > d3)
+            {
+                if(d2 < m_distance_tolerance_square)
+                {
+                    m_points.add(point_d(x2, y2));
+                    return;
+                }
+            }
+            else
+            {
+                if(d3 < m_distance_tolerance_square)
+                {
+                    m_points.add(point_d(x3, y3));
+                    return;
+                }
+            }
             break;
 
         case 1:
-            // p1,p2,p4 are collinear, p3 is considerable
+            // p1,p2,p4 are collinear, p3 is significant
             //----------------------
             if(d3 * d3 <= m_distance_tolerance_square * (dx*dx + dy*dy))
             {
@@ -469,7 +511,7 @@ namespace agg24
             break;
 
         case 2:
-            // p1,p3,p4 are collinear, p2 is considerable
+            // p1,p3,p4 are collinear, p2 is significant
             //----------------------
             if(d2 * d2 <= m_distance_tolerance_square * (dx*dx + dy*dy))
             {
@@ -503,7 +545,7 @@ namespace agg24
             break;
 
         case 3: 
-            // Regular care
+            // Regular case
             //-----------------
             if((d2 + d3)*(d2 + d3) <= m_distance_tolerance_square * (dx*dx + dy*dy))
             {
@@ -518,9 +560,9 @@ namespace agg24
 
                 // Angle & Cusp Condition
                 //----------------------
-                double a23 = atan2(y3 - y2, x3 - x2);
-                da1 = fabs(a23 - atan2(y2 - y1, x2 - x1));
-                da2 = fabs(atan2(y4 - y3, x4 - x3) - a23);
+                k   = atan2(y3 - y2, x3 - x2);
+                da1 = fabs(k - atan2(y2 - y1, x2 - x1));
+                da2 = fabs(atan2(y4 - y3, x4 - x3) - k);
                 if(da1 >= pi) da1 = 2*pi - da1;
                 if(da2 >= pi) da2 = 2*pi - da2;
 
