@@ -40,10 +40,30 @@ namespace agg24
     //------------------------------------------------------------------------
     void trans_warp_magnifier::inverse_transform(double* x, double* y) const
     {
-        trans_warp_magnifier t(*this);
-        t.magnification(1.0 / m_magn);
-        t.radius(m_radius * m_magn);
-        t.transform(x, y);
+        // New version by Andrew Skalkin
+        //-----------------
+        double dx = *x - m_xc;
+        double dy = *y - m_yc;
+        double r = sqrt(dx * dx + dy * dy);
+
+        if(r < m_radius * m_magn)
+        {
+            *x = m_xc + dx / m_magn;
+            *y = m_yc + dy / m_magn;
+        }
+        else
+        {
+            double rnew = r - m_radius * (m_magn - 1.0);
+            *x = m_xc + rnew * dx / r;
+            *y = m_yc + rnew * dy / r;
+        }
+
+        // Old version
+        //-----------------
+        //trans_warp_magnifier t(*this);
+        //t.magnification(1.0 / m_magn);
+        //t.radius(m_radius * m_magn);
+        //t.transform(x, y);
     }
 
 
