@@ -10,13 +10,10 @@
 #include <string.h>
 #include <stack>
 
-#if defined(_WIN32) || defined(__WIN32__) || defined(__CYGWIN__)
-#include <windows.h>
-#endif
-
 #include <iostream>
 #include <memory>
-#include <locale>
+
+#include "utf8.h"
 
 #include "agg_trans_affine.h"
 #include "agg_path_storage.h"
@@ -57,6 +54,7 @@
 #include "kiva_alpha_gamma.h"
 #include "kiva_gradient.h"
 
+
 namespace kiva
 {
 
@@ -588,7 +586,7 @@ namespace kiva
 
 
             agg24::path_storage img_outline = img.boundary_path(img_mtx);
-            agg24::rendering_buffer* src_buf = img.rendering_buffer_ptr();
+            other_format src_pix(img.rendering_buffer());
 
             agg24::trans_affine inv_img_mtx = img_mtx;
             inv_img_mtx.invert();
@@ -605,7 +603,7 @@ namespace kiva
                     typedef typename kiva::image_filters<other_format>::nearest_type span_gen_type;
                     typedef typename kiva::image_filters<other_format>::source_type source_type;
 
-                    source_type source(*src_buf, back_color);
+                    source_type source(src_pix, back_color);
                     span_gen_type span_generator(source, interpolator);
                     this->transform_image_final(img_outline, span_generator);
 					break;
@@ -615,7 +613,7 @@ namespace kiva
                     typedef typename kiva::image_filters<other_format>::bilinear_type span_gen_type;
                     typedef typename kiva::image_filters<other_format>::source_type source_type;
 
-                    source_type source(*src_buf, back_color);
+                    source_type source(src_pix, back_color);
                     span_gen_type span_generator(source, interpolator);
                     this->transform_image_final(img_outline, span_generator);
                     break;
@@ -669,7 +667,7 @@ namespace kiva
                     typedef typename kiva::image_filters<other_format>::general_type span_gen_type;
                     typedef typename kiva::image_filters<other_format>::source_type source_type;
 
-                    source_type source(*src_buf, back_color);
+                    source_type source(src_pix, back_color);
                     span_gen_type span_generator(source, interpolator, filter);
                     this->transform_image_final(img_outline, span_generator);
 
@@ -1292,21 +1290,13 @@ namespace kiva
         ScanlineRendererType scanlineRenderer(this->renderer);
 
         const agg24::glyph_cache *glyph = NULL;
-#if defined(_WIN32) || defined(__WIN32__) || defined(__CYGWIN__)
-        int required = MultiByteToWideChar(CP_UTF8, 0, text, -1, 0, 0);
-        std::vector<wchar_t> p_(required + 1);
-        MultiByteToWideChar(CP_UTF8, 0, text, -1, &p_[0], required);
-        wchar_t *p = &p_[0];
-#else
-        std::vector <wchar_t> p_(1024);
-        size_t length = mbstowcs(&p_[0], text, 1024);
-        if (length > 1024)
-          {
-            p_.resize (length + 1);
-            mbstowcs(&p_[0], text, length);
-          }
-        wchar_t *p = &p_[0];
-#endif
+
+        // Explicitly decode UTF8 bytes to 32-bit codepoints to feed into the
+        // font API.
+        size_t text_length = strlen(text);
+        utf8::iterator<char*> p(text, text, text+text_length);
+        utf8::iterator<char*> p_end(text+text_length, text, text+text_length);
+
         bool retval = true;
 
         // Check to make sure the font's loaded.
@@ -1353,7 +1343,7 @@ namespace kiva
         double advance_x = 0.0;
         double advance_y = 0.0;
 
-        while (*p)
+        for (; p!=p_end; ++p)
         {
             double x = start_x + advance_x;
             double y = start_y + advance_y;
@@ -1375,7 +1365,6 @@ namespace kiva
 
             advance_x += glyph->advance_x;
             advance_y += glyph->advance_y;
-            p++;
         }
 
         agg24::trans_affine null_xform = agg24::trans_affine_translation(0., 0.);
