@@ -1,4 +1,6 @@
-from string import lowercase, uppercase
+from __future__ import print_function
+
+from string import ascii_lowercase, ascii_uppercase
 import os
 import time
 
@@ -6,7 +8,7 @@ from kiva.image import font_metrics_provider as FMP
 from kiva.fonttools import Font
 
 counts = (500,)
-strings = ("hello", ) # lowercase + uppercase)
+strings = ("hello", ) # ascii_lowercase + ascii_uppercase)
 fonts = ( ("arial", 12), ) # ("times", 16), ("courier", 10) )
 
 def test():
@@ -22,9 +24,9 @@ def test():
                     dims = metrics.get_text_extent(s)
             allmetrics.append(metrics)
         end = time.time()
-        print "finished count=%d" % count
-        print "   total time:", end - start
-        print "   time/set_font:", (end-start) / float(count * len(fonts))
+        print("finished count=%d" % count)
+        print("   total time:", end - start)
+        print("   time/set_font:", (end-start) / float(count * len(fonts)))
 
 if __name__ == "__main__":
     test()
