@@ -54,7 +54,7 @@ from numpy import array, alltrue, ravel
 from kiva.agg import GraphicsContextArray
 import kiva
 
-from test_utils import Utils
+from .test_utils import Utils
 
 
 class StrokePathTestCase(unittest.TestCase, Utils):
@@ -462,7 +462,7 @@ class StrokePathTestCase(unittest.TestCase, Utils):
         x2, y2 = 6.0, 1.0
         x3, y3 = 9.0, 5.0
         gc.move_to(x0, y0)
-        gc.curve_to(x1, y1, x2, y2, x3, y3);
+        gc.curve_to(x1, y1, x2, y2, x3, y3)
 
         # Set up stroke
         gc. set_stroke_color((0.0, 0.0, 0.0)) # black
@@ -487,8 +487,8 @@ class StrokePathTestCase(unittest.TestCase, Utils):
                          [255, 255, 231,  25, 212, 255, 255, 255, 255, 255],
                          [255, 252,  65, 128, 255, 255, 255, 255, 255, 255],
                          [255, 103,  26, 143, 229, 255, 255, 255, 255, 255],
-                         [179,   2, 115,  96,  23, 189, 255, 255, 204, 255],
-                         [255, 205, 255, 255, 189,  23,  97, 116,   2, 179],
+                         [180,   2, 118,  96,  23, 189, 255, 255, 205, 255],
+                         [255, 206, 255, 255, 189,  23,  97, 119,   2, 180],
                          [255, 255, 255, 255, 255, 229, 142,  25, 103, 255],
                          [255, 255, 255, 255, 255, 255, 127,  66, 252, 255],
                          [255, 255, 255, 255, 255, 212,  26, 231, 255, 255],
