@@ -5,10 +5,11 @@ specification strings into Font instances.
 
 from __future__ import absolute_import, print_function
 
+import six
+
 import copy
 from kiva.constants import (DEFAULT, DECORATIVE, ROMAN, SCRIPT, SWISS, MODERN,
                             TELETYPE, NORMAL, ITALIC, BOLD, BOLD_ITALIC)
-from .font_manager import FontProperties, fontManager
 
 # Various maps used by str_to_font
 font_families = {
@@ -81,13 +82,14 @@ class Font(object):
     def __init__(self, face_name="", size=12, family=SWISS, weight=NORMAL,
                  style=NORMAL, underline=0, encoding=DEFAULT):
         if (type(size) != int) or (type(family) != type(SWISS)) or \
-                (type(weight) != type(NORMAL)) or (type(style) != type(NORMAL)) or \
-                (type(underline) != int) or (not isinstance(face_name, basestring)) or \
-                (type(encoding) != type(DEFAULT)):
-            raise RuntimeError("Bad value in Font() constructor.")
-        # HACK:  C++ stuff expects a string (not unicode) for the face_name,
-        #        so fix if needed.  See ticket #2111 in the CP Trac.
-        if isinstance(face_name, unicode):
+            (type(weight) != type(NORMAL)) or (type(style) != type(NORMAL)) or \
+            (type(underline) != int) or (not isinstance(face_name, six.string_types)) or \
+            (type(encoding) != type(DEFAULT)):
+                raise RuntimeError("Bad value in Font() constructor.")
+        ### HACK:  C++ stuff expects a string (not unicode) for the face_name, so fix
+        ###        if needed.
+        ### Only for python < 3
+        if six.PY2 and isinstance(face_name, six.text_type):
             face_name = face_name.encode("latin1")
         self.size = size
         self.family = family
@@ -101,6 +103,8 @@ class Font(object):
         """ Returns the file name containing the font that most closely matches
         our font properties.
         """
+        from .font_manager import fontManager
+
         fp = self._make_font_props()
         return str(fontManager.findfont(fp))
 
@@ -115,6 +119,8 @@ class Font(object):
         """ Returns a font_manager.FontProperties object that encapsulates our
         font properties
         """
+        from .font_manager import FontProperties
+
         # XXX: change the weight to a numerical value
         if self.style == BOLD or self.style == BOLD_ITALIC:
             weight = "bold"
