@@ -24,9 +24,7 @@ constant ``USE_FONTCONFIG`` in this file to ``True``.  Fontconfig has
 the advantage that it is the standard way to look up fonts on X11
 platforms, so if a font is installed, it is much more likely to be
 found.
-"""
 
-"""
 KNOWN ISSUES
 
   - documentation
@@ -48,80 +46,84 @@ License   : matplotlib license (PSF compatible)
             see license/LICENSE_TTFQUERY.
 """
 
-import os, sys, glob, subprocess, warnings, tempfile, errno
-try:
-    set
-except NameError:
-    from sets import Set as set
-import afm
+from __future__ import absolute_import, print_function
 
+import logging
+import os
+import sys
+import glob
+import subprocess
+import warnings
+import tempfile
+import errno
+
+import six
+import six.moves as sm
+
+from fontTools.ttLib import TTCollection, TTFont, TTLibError
 from traits.etsconfig.api import ETSConfig
-from kiva.fonttools.fontTools.ttLib import TTFont
 
-try:
-    import cPickle as pickle
-except ImportError:
-    import pickle
+from . import afm
+
+logger = logging.getLogger(__name__)
 
 USE_FONTCONFIG = False
 
 font_scalings = {
-    'xx-small' : 0.579,
-    'x-small'  : 0.694,
-    'small'    : 0.833,
-    'medium'   : 1.0,
-    'large'    : 1.200,
-    'x-large'  : 1.440,
-    'xx-large' : 1.728,
-    'larger'   : 1.2,
-    'smaller'  : 0.833,
-    None       : 1.0}
+    'xx-small': 0.579,
+    'x-small': 0.694,
+    'small': 0.833,
+    'medium': 1.0,
+    'large': 1.200,
+    'x-large': 1.440,
+    'xx-large': 1.728,
+    'larger': 1.2,
+    'smaller': 0.833,
+    None: 1.0
+}
 
 stretch_dict = {
-    'ultra-condensed' : 100,
-    'extra-condensed' : 200,
-    'condensed'       : 300,
-    'semi-condensed'  : 400,
-    'normal'          : 500,
-    'semi-expanded'   : 600,
-    'expanded'        : 700,
-    'extra-expanded'  : 800,
-    'ultra-expanded'  : 900}
+    'ultra-condensed': 100,
+    'extra-condensed': 200,
+    'condensed': 300,
+    'semi-condensed': 400,
+    'normal': 500,
+    'semi-expanded': 600,
+    'expanded': 700,
+    'extra-expanded': 800,
+    'ultra-expanded': 900
+}
 
 weight_dict = {
-    'ultralight' : 100,
-    'light'      : 200,
-    'normal'     : 400,
-    'regular'    : 400,
-    'book'       : 400,
-    'medium'     : 500,
-    'roman'      : 500,
-    'semibold'   : 600,
-    'demibold'   : 600,
-    'demi'       : 600,
-    'bold'       : 700,
-    'heavy'      : 800,
-    'extra bold' : 800,
-    'black'      : 900}
+    'ultralight': 100,
+    'light': 200,
+    'normal': 400,
+    'regular': 400,
+    'book': 400,
+    'medium': 500,
+    'roman': 500,
+    'semibold': 600,
+    'demibold': 600,
+    'demi': 600,
+    'bold': 700,
+    'heavy': 800,
+    'extra bold': 800,
+    'black': 900
+}
 
-font_family_aliases = set([
-        'serif',
-        'sans-serif',
-        'sans serif',
-        'cursive',
-        'fantasy',
-        'monospace',
-        'sans'])
+font_family_aliases = set(['serif', 'sans-serif', 'sans serif', 'cursive',
+                           'fantasy', 'monospace', 'sans', 'modern'])
 
 #  OS Font paths
 MSFolders = \
     r'Software\Microsoft\Windows\CurrentVersion\Explorer\Shell Folders'
 
-MSFontDirectories   = [
+MSFontDirectories = [
     r'SOFTWARE\Microsoft\Windows NT\CurrentVersion\Fonts',
-    r'SOFTWARE\Microsoft\Windows\CurrentVersion\Fonts']
+    r'SOFTWARE\Microsoft\Windows\CurrentVersion\Fonts'
+]
 
-X11FontDirectories  = [
+X11FontDirectories = [
     # an old standard installation point
     "/usr/X11R6/lib/X11/fonts/TTF/",
     # here is the new standard location for fonts
@@ -130,7 +132,7 @@ X11FontDirectories  = [
     "/usr/local/share/fonts/",
     # common application, not really useful
     "/usr/lib/openoffice/share/fonts/truetype/",
-    ]
+]
 
 OSXFontDirectories = [
     "/Library/Fonts/",
@@ -152,39 +154,41 @@ if not USE_FONTCONFIG:
 ###############################################################################
 
 preferred_fonts = {
-    'fantasy': ['Comic Sans MS', 'Chicago', 'Charcoal', 'ImpactWestern', 'fantasy'],
-    'cursive': ['Apple Chancery', 'Textile', 'Zapf Chancery', 'Sand', 'cursive'],
-    'monospace': ['Bitstream Vera Sans Mono', 'DejaVu Sans Mono', 'Andale Mono', 'Nimbus Mono L', 'Courier New', 'Courier', 'Fixed', 'Terminal', 'monospace'],
-    'serif': ['Bitstream Vera Serif', 'DejaVu Serif', 'New Century Schoolbook', 'Century Schoolbook L', 'Utopia', 'ITC Bookman', 'Bookman', 'Nimbus Roman No9 L', 'Times New Roman', 'Times', 'Palatino', 'Charter', 'serif'],
-    'sans-serif': ['Bitstream Vera Sans', 'DejaVu Sans', 'Lucida Grande', 'Verdana', 'Geneva', 'Lucid', 'Arial', 'Helvetica', 'Avant Garde', 'sans-serif']
+    'fantasy': ['Comic Sans MS', 'Chicago', 'Charcoal', 'ImpactWestern',
+                'fantasy'],
+    'cursive': ['Apple Chancery', 'Textile', 'Zapf Chancery', 'Sand',
+                'cursive'],
+    'monospace': ['Bitstream Vera Sans Mono', 'DejaVu Sans Mono',
+                  'Andale Mono', 'Nimbus Mono L', 'Courier New', 'Courier',
+                  'Fixed', 'Terminal', 'monospace'],
+    'serif': ['Bitstream Vera Serif', 'DejaVu Serif', 'New Century Schoolbook',
+              'Century Schoolbook L', 'Utopia', 'ITC Bookman', 'Bookman',
+              'Nimbus Roman No9 L', 'Times New Roman', 'Times', 'Palatino',
+              'Charter', 'serif'],
+    'sans-serif': ['Bitstream Vera Sans', 'DejaVu Sans', 'Lucida Grande',
+                   'Verdana', 'Geneva', 'Lucid', 'Arial', 'Helvetica',
+                   'Avant Garde', 'sans-serif']
 }
 
-class verbose(object):
-    ''' class to fake matplotlibs verbose module. No idea why logging
-        module isnt used instead
-    '''
-    @staticmethod
-    def report(text, level='info'):
-        return
-        #print "kiva font_manager: ", text
 
 def _is_writable_dir(p):
     """
     p is a string pointing to a putative writable dir -- return True p
     is such a string, else False
     """
-    if not isinstance(p, basestring):
+    if not isinstance(p, six.string_types):
         return False
 
     try:
         t = tempfile.TemporaryFile(dir=p)
-        t.write('kiva.test')
+        t.write(b'kiva.test')
         t.close()
     except OSError:
         return False
     else:
         return True
 
+
 def get_configdir():
     """
     Return the string representing the configuration dir.  If s is the
@@ -194,18 +198,19 @@ def get_configdir():
     p = os.path.join(ETSConfig.application_data, 'kiva')
     try:
         os.makedirs(p)
-    except OSError, e:
+    except OSError as e:
         if e.errno != errno.EEXIST:
             raise
     if not _is_writable_dir(p):
         raise IOError('Configuration directory %s must be writable' % p)
     return p
 
+
 def is_string_like(obj):
     'Return True if *obj* looks like a string'
     from numpy import ma
 
-    if isinstance(obj, (str, unicode)):
+    if isinstance(obj, six.string_types):
         return True
     # numpy strings are subclass of str, ma strings are not
     if ma.isMaskedArray(obj):
@@ -213,57 +218,93 @@ def is_string_like(obj):
             return True
         else:
             return False
-        try: obj + ''
-        except: return False
+        try:
+            obj + ''
+        except Exception:
+            return False
         return True
 
+
+def decode_prop(prop):
+    """ Decode a prop string.
+
+    Parameters
+    ----------
+    prop : bytestring
+
+    Returns
+    -------
+    string
+    """
+    # Adapted from: https://gist.github.com/pklaus/dce37521579513c574d0
+    encoding = "utf-16-be" if b"\x00" in prop else "utf-8"
+
+    return prop.decode(encoding)
+
+
 def getPropDict(font):
     n = font['name']
     propdict = {}
     for prop in n.names:
-        propdict[(prop.platformID, prop.platEncID, prop.langID, prop.nameID )] = prop.string
+        try:
+            if 'name' in propdict and 'sfnt4' in propdict:
+                break
+            elif prop.nameID == 1 and 'name' not in propdict:
+                propdict['name'] = decode_prop(prop.string)
+            elif prop.nameID == 4 and 'sfnt4' not in propdict:
+                propdict['sfnt4'] = decode_prop(prop.string)
+        except UnicodeDecodeError:
+            continue
+
     return propdict
+
+
 ###############################################################################
 #  matplotlib code below
 ###############################################################################
 
+synonyms = {'ttf': ('ttf', 'otf', 'ttc'),
+            'otf': ('ttf', 'otf', 'ttc'),
+            'ttc': ('ttf', 'otf', 'ttc'),
+            'afm': ('afm',)}
+
 
 def get_fontext_synonyms(fontext):
     """
     Return a list of file extensions extensions that are synonyms for
     the given file extension *fileext*.
     """
-    return {'ttf': ('ttf', 'otf'),
-            'otf': ('ttf', 'otf'),
-            'afm': ('afm',)}[fontext]
+    return synonyms[fontext]
+
 
 def win32FontDirectory():
     """
     Return the user-specified font directory for Win32.  This is
     looked up from the registry key::
 
-      \\HKEY_CURRENT_USER\Software\Microsoft\Windows\CurrentVersion\Explorer\Shell Folders\Fonts
+      \\HKEY_CURRENT_USER\Software\Microsoft\Windows\CurrentVersion\Explorer\Shell Folders\Fonts       # noqa
 
     If the key is not found, $WINDIR/Fonts will be returned.
     """
     try:
-        import _winreg
+        from six.moves import winreg
     except ImportError:
-        pass # Fall through to default
+        pass  # Fall through to default
     else:
         try:
-            user = _winreg.OpenKey(_winreg.HKEY_CURRENT_USER, MSFolders)
+            user = winreg.OpenKey(winreg.HKEY_CURRENT_USER, MSFolders)
             try:
                 try:
-                    return _winreg.QueryValueEx(user, 'Fonts')[0]
+                    return winreg.QueryValueEx(user, 'Fonts')[0]
                 except OSError:
-                    pass # Fall through to default
+                    pass  # Fall through to default
             finally:
-                _winreg.CloseKey(user)
+                winreg.CloseKey(user)
         except OSError:
-            pass # Fall through to default
+            pass  # Fall through to default
     return os.path.join(os.environ['WINDIR'], 'Fonts')
 
+
 def win32InstalledFonts(directory=None, fontext='ttf'):
     """
     Search for fonts in the specified font directory, or use the
@@ -272,7 +313,7 @@ def win32InstalledFonts(directory=None, fontext='ttf'):
     'afm'.
     """
 
-    import _winreg
+    from six.moves import winreg
     if directory is None:
         directory = win32FontDirectory()
 
@@ -281,7 +322,7 @@ def win32InstalledFonts(directory=None, fontext='ttf'):
     key, items = None, {}
     for fontdir in MSFontDirectories:
         try:
-            local = _winreg.OpenKey(_winreg.HKEY_LOCAL_MACHINE, fontdir)
+            local = winreg.OpenKey(winreg.HKEY_LOCAL_MACHINE, fontdir)
         except OSError:
             continue
 
@@ -291,9 +332,9 @@ def win32InstalledFonts(directory=None, fontext='ttf'):
                 files.extend(glob.glob(os.path.join(directory, '*.'+ext)))
             return files
         try:
-            for j in range(_winreg.QueryInfoKey(local)[1]):
+            for j in sm.range(winreg.QueryInfoKey(local)[1]):
                 try:
-                    key, direc, any = _winreg.EnumValue( local, j)
+                    key, direc, any = winreg.EnumValue(local, j)
                     if not os.path.dirname(direc):
                         direc = os.path.join(directory, direc)
                     direc = os.path.abspath(direc).lower()
@@ -304,11 +345,12 @@ def win32InstalledFonts(directory=None, fontext='ttf'):
                 except WindowsError:
                     continue
 
-            return items.keys()
+            return list(items.keys())
         finally:
-            _winreg.CloseKey(local)
+            winreg.CloseKey(local)
     return None
 
+
 def OSXFontDirectory():
     """
     Return the system font directories for OS X.  This is done by
@@ -316,18 +358,21 @@ def OSXFontDirectory():
     :attr:`OSXFontDirectories` and returning all nested directories
     within them.
     """
+
     fontpaths = []
-    def add(arg,directory,files):
-        fontpaths.append(directory)
 
     for fontdir in OSXFontDirectories:
         try:
             if os.path.isdir(fontdir):
-                os.path.walk(fontdir, add, None)
+                fontpaths.append(fontdir)
+                for dirpath, dirs, _files in os.walk(fontdir):
+                    fontpaths.extend([os.path.join(dirpath, d) for d in dirs])
+
         except (IOError, OSError, TypeError, ValueError):
             pass
     return fontpaths
 
+
 def OSXInstalledFonts(directory=None, fontext='ttf'):
     """
     Get list of font files on OS X - ignores font suffix by default.
@@ -340,7 +385,7 @@ def OSXInstalledFonts(directory=None, fontext='ttf'):
     files = []
     for path in directory:
         if fontext is None:
-            files.extend(glob.glob(os.path.join(path,'*')))
+            files.extend(glob.glob(os.path.join(path, '*')))
         else:
             for ext in fontext:
                 files.extend(glob.glob(os.path.join(path, '*.'+ext)))
@@ -356,13 +401,14 @@ def x11FontDirectory():
     within them.
     """
     fontpaths = []
-    def add(arg,directory,files):
-        fontpaths.append(directory)
 
     for fontdir in X11FontDirectories:
         try:
             if os.path.isdir(fontdir):
-                os.path.walk(fontdir, add, None)
+                fontpaths.append(fontdir)
+                for dirpath, dirs, _files in os.walk(fontdir):
+                    fontpaths.extend([os.path.join(dirpath, d) for d in dirs])
+
         except (IOError, OSError, TypeError, ValueError):
             pass
     return fontpaths
@@ -379,21 +425,24 @@ def get_fontconfig_fonts(fontext='ttf'):
 
     fontfiles = {}
     try:
-        pipe = subprocess.Popen(['fc-list', '', 'file'], stdout=subprocess.PIPE)
+        pipe = subprocess.Popen(['fc-list', '', 'file'],
+                                stdout=subprocess.PIPE)
         output = pipe.communicate()[0]
     except OSError:
         # Calling fc-list did not work, so we'll just return nothing
         return fontfiles
 
+    output = output.decode('utf8')
     if pipe.returncode == 0:
         for line in output.split('\n'):
             fname = line.split(':')[0]
             if (os.path.splitext(fname)[1][1:] in fontext and
-                os.path.exists(fname)):
+                    os.path.exists(fname)):
                 fontfiles[fname] = 1
 
     return fontfiles
 
+
 def findSystemFonts(fontpaths=None, fontext='ttf'):
     """
     Search for fonts in the specified font paths.  If no paths are
@@ -413,19 +462,22 @@ def findSystemFonts(fontpaths=None, fontext='ttf'):
             # now get all installed fonts directly...
             for f in win32InstalledFonts(fontdir):
                 base, ext = os.path.splitext(f)
-                if len(ext)>1 and ext[1:].lower() in fontexts:
+                if len(ext) > 1 and ext[1:].lower() in fontexts:
                     fontfiles[f] = 1
         else:
-            fontpaths = x11FontDirectory()
             # check for OS X & load its fonts if present
             if sys.platform == 'darwin':
+                fontpaths = []
                 for f in OSXInstalledFonts(fontext=fontext):
                     fontfiles[f] = 1
+            else:
+                # Otherwise, check X11.
+                fontpaths = x11FontDirectory()
 
             for f in get_fontconfig_fonts(fontext):
                 fontfiles[f] = 1
 
-    elif isinstance(fontpaths, (str, unicode)):
+    elif isinstance(fontpaths, six.string_types):
         fontpaths = [fontpaths]
 
     for path in fontpaths:
@@ -436,7 +488,8 @@ def findSystemFonts(fontpaths=None, fontext='ttf'):
         for fname in files:
             abs_path = os.path.abspath(fname)
 
-            # Handle dirs which look like font files, but may contain font files
+            # Handle dirs which look like font files, but may contain font
+            # files
             if os.path.isdir(abs_path):
                 fontpaths.append(abs_path)
             else:
@@ -444,6 +497,7 @@ def findSystemFonts(fontpaths=None, fontext='ttf'):
 
     return [fname for fname in fontfiles.keys() if os.path.exists(fname)]
 
+
 def weight_as_number(weight):
     """
     Return the weight property as a numeric value.  String values
@@ -457,7 +511,7 @@ def weight_as_number(weight):
     elif weight in range(100, 1000, 100):
         pass
     else:
-        raise ValueError, 'weight not a valid integer'
+        raise ValueError('weight not a valid integer')
     return weight
 
 
@@ -466,20 +520,13 @@ class FontEntry(object):
     A class for storing Font properties.  It is used when populating
     the font lookup dictionary.
     """
-    def __init__(self,
-                 fname  ='',
-                 name   ='',
-                 style  ='normal',
-                 variant='normal',
-                 weight ='normal',
-                 stretch='normal',
-                 size   ='medium',
-                 ):
-        self.fname   = fname
-        self.name    = name
-        self.style   = style
+    def __init__(self, fname='', name='', style='normal', variant='normal',
+                 weight='normal', stretch='normal', size='medium'):
+        self.fname = fname
+        self.name = name
+        self.style = style
         self.variant = variant
-        self.weight  = weight
+        self.weight = weight
         self.stretch = stretch
         try:
             self.size = str(float(size))
@@ -500,36 +547,20 @@ def ttfFontProperty(fpath, font):
     *font* is a :class:`FT2Font` instance.
     """
     props = getPropDict(font)
-    name = props[(1,0,0,1)]
+    name = props.get('name')
+    if name is None:
+        raise KeyError("No name could be found for: {}".format(fpath))
 
     #  Styles are: italic, oblique, and normal (default)
+    sfnt4 = props.get('sfnt4', '')
 
-    try:
-        sfnt2 = props[(1,0,0,2)]
-    except:
-        sfnt2 = None
-    try:
-        sfnt4 = props[(1,0,0,4)]
-    except:
-        sfnt4 = None
-    if sfnt2:
-        sfnt2 = sfnt2.lower()
-    else:
-        sfnt2 = ''
-    if sfnt4:
-        sfnt4 = sfnt4.lower()
-    else:
-        sfnt4 = ''
-    if   sfnt4.find('oblique') >= 0:
+    if sfnt4.find('oblique') >= 0:
         style = 'oblique'
     elif sfnt4.find('italic') >= 0:
         style = 'italic'
-    elif sfnt2.find('regular') >= 0:
-        style = 'normal'
     else:
         style = 'normal'
 
-
     #  Variants are: small-caps and normal (default)
 
     #  !!!!  Untested
@@ -558,8 +589,8 @@ def ttfFontProperty(fpath, font):
     #  Relative stretches are: wider, narrower
     #  Child value is: inherit
 
-    if sfnt4.find('narrow') >= 0 or sfnt4.find('condensed') >= 0 or \
-           sfnt4.find('cond') >= 0:
+    if (sfnt4.find('narrow') >= 0 or sfnt4.find('condensed') >= 0 or
+            sfnt4.find('cond') >= 0):
         stretch = 'condensed'
     elif sfnt4.find('demi cond') >= 0:
         stretch = 'semi-condensed'
@@ -578,9 +609,6 @@ def ttfFontProperty(fpath, font):
     #  !!!!  Incomplete
     size = 'scalable'
 
-    #  !!!!  Incomplete
-    size_adjust = None
-
     return FontEntry(fpath, name, style, variant, weight, stretch, size)
 
 
@@ -624,8 +652,8 @@ def afmFontProperty(fontpath, font):
     #    and ultra-expanded.
     #  Relative stretches are: wider, narrower
     #  Child value is: inherit
-    if fontname.find('narrow') >= 0 or fontname.find('condensed') >= 0 or \
-           fontname.find('cond') >= 0:
+    if (fontname.find('narrow') >= 0 or fontname.find('condensed') >= 0 or
+            fontname.find('cond') >= 0):
         stretch = 'condensed'
     elif fontname.find('demi cond') >= 0:
         stretch = 'semi-condensed'
@@ -645,31 +673,32 @@ def afmFontProperty(fontpath, font):
 
     size = 'scalable'
 
-    # !!!!  Incomplete
-    size_adjust = None
-
     return FontEntry(fontpath, name, style, variant, weight, stretch, size)
 
+
 def createFontList(fontfiles, fontext='ttf'):
     """
     A function to create a font lookup list.  The default is to create
     a list of TrueType fonts.  An AFM font list can optionally be
     created.
     """
-
+    # FIXME: This function is particularly difficult to debug
     fontlist = []
     #  Add fonts from list of known font files.
     seen = {}
     for fpath in fontfiles:
-        verbose.report('createFontDict: %s' % (fpath), 'debug')
+        logger.debug("createFontDict %s", fpath)
         fname = os.path.split(fpath)[1]
-        if fname in seen:  continue
-        else: seen[fname] = 1
+        if fname in seen:
+            continue
+        else:
+            seen[fname] = 1
         if fontext == 'afm':
             try:
                 fh = open(fpath, 'r')
-            except:
-                verbose.report("Could not open font file %s" % fpath)
+            except Exception:
+                logger.error(
+                    "Could not open font file %s", fpath, exc_info=True)
                 continue
             try:
                 try:
@@ -677,28 +706,58 @@ def createFontList(fontfiles, fontext='ttf'):
                 finally:
                     fh.close()
             except RuntimeError:
-                verbose.report("Could not parse font file %s"%fpath)
+                logger.error(
+                    "Could not parse font file %s", fpath, exc_info=True)
                 continue
             try:
                 prop = afmFontProperty(fpath, font)
-            except:
+            except Exception:
+                logger.error(
+                    "Could not covert font to FontEntry for file %s", fpath,
+                    exc_info=True
+                )
                 continue
         else:
+            _, ext = os.path.splitext(fpath)
             try:
-                font = TTFont(str(fpath))
-            except RuntimeError:
-                verbose.report("Could not open font file %s"%fpath)
+                if ext.lower() == ".ttc":
+                    collection = TTCollection(six.text_type(fpath))
+                    try:
+                        props = []
+                        for font in collection.fonts:
+                            props.append(ttfFontProperty(fpath, font))
+                        fontlist.extend(props)
+                        continue
+                    except Exception:
+                        logger.error(
+                            "Could not covert font to FontEntry for file %s",
+                            fpath, exc_info=True
+                        )
+                        continue
+                else:
+                    font = TTFont(six.text_type(fpath))
+            except (RuntimeError, TTLibError):
+                logger.error(
+                    "Could not open font file %s", fpath, exc_info=True)
                 continue
             except UnicodeError:
-                verbose.report("Cannot handle unicode filenames")
-                #print >> sys.stderr, 'Bad file is', fpath
+                logger.error(
+                    "Cannot handle unicode file: %s", fpath, exc_info=True)
+                continue
+
+            try:
+                prop = ttfFontProperty(fpath, font)
+            except Exception:
+                logger.error(
+                    "Could not covert font to FontEntry for file %s", fpath,
+                    exc_info=True
+                )
                 continue
-            try: prop = ttfFontProperty(fpath, font)
-            except: continue
 
         fontlist.append(prop)
     return fontlist
 
+
 class FontProperties(object):
     """
     A class for storing and manipulating font properties.
@@ -758,16 +817,11 @@ class FontProperties(object):
     fontconfig.
     """
 
-    def __init__(self,
-                 family = None,
-                 style  = None,
-                 variant= None,
-                 weight = None,
-                 stretch= None,
-                 size   = None,
-                 fname  = None, # if this is set, it's a hardcoded filename to use
-                 _init   = None  # used only by copy()
-                 ):
+    def __init__(self, family=None, style=None, variant=None, weight=None,
+                 stretch=None, size=None, fname=None, _init=None):
+        # if fname is set, it's a hardcoded filename to use
+        # _init is used only by copy()
+
         self._family = None
         self._slant = None
         self._variant = None
@@ -784,12 +838,8 @@ class FontProperties(object):
         if is_string_like(family):
             # Treat family as a fontconfig pattern if it is the only
             # parameter provided.
-            if (style is None and
-                variant is None and
-                weight is None and
-                stretch is None and
-                size is None and
-                fname is None):
+            if (style is None and variant is None and weight is None and
+                    stretch is None and size is None and fname is None):
                 self.set_fontconfig_pattern(family)
                 return
 
@@ -802,8 +852,8 @@ class FontProperties(object):
         self.set_size(size)
 
     def __hash__(self):
-        l = [(k, getattr(self, "get" + k)()) for k in sorted(self.__dict__)]
-        return hash(repr(l))
+        lst = [(k, getattr(self, "get" + k)()) for k in sorted(self.__dict__)]
+        return hash(repr(lst))
 
     def __str__(self):
         return str((self._family, self._slant, self._variant,
@@ -820,11 +870,13 @@ class FontProperties(object):
         Return the name of the font that best matches the font
         properties.
         """
-        filename = str(fontManager.findfont(self))
+        filename = six.text_type(fontManager.findfont(self))
         if filename.endswith('.afm'):
-            return afm.AFM(file(filename)).get_familyname()
+            return afm.AFM(open(filename)).get_familyname()
 
-        return getPropDict(TTFont(str(fontManager.findfont(self))))[(1,0,0,1)]
+        font = fontManager.findfont(self)
+        prop_dict = getPropDict(TTFont(six.text_type(font)))
+        return prop_dict['name']
 
     def get_style(self):
         """
@@ -888,6 +940,8 @@ class FontProperties(object):
         if family is None:
             self._family = None
         else:
+            if '' != b'' and isinstance(family, bytes):
+                family = family.decode('utf8')
             if is_string_like(family):
                 family = [family]
             self._family = family
@@ -970,7 +1024,8 @@ class FontProperties(object):
 
     def copy(self):
         """Return a deep copy of self"""
-        return FontProperties(_init = self)
+        return FontProperties(_init=self)
+
 
 def ttfdict_to_fnames(d):
     """
@@ -986,29 +1041,32 @@ def ttfdict_to_fnames(d):
                             fnames.append(fname)
     return fnames
 
+
 def pickle_dump(data, filename):
     """
-    Equivalent to pickle.dump(data, open(filename, 'w'))
+    Equivalent to pickle.dump(data, open(filename, 'wb'))
     but closes the file to prevent filehandle leakage.
     """
-    fh = open(filename, 'w')
+    fh = open(filename, 'wb')
     try:
-        pickle.dump(data, fh)
+        sm.cPickle.dump(data, fh)
     finally:
         fh.close()
 
+
 def pickle_load(filename):
     """
-    Equivalent to pickle.load(open(filename, 'r'))
+    Equivalent to pickle.load(open(filename, 'rb'))
     but closes the file to prevent filehandle leakage.
     """
-    fh = open(filename, 'r')
+    fh = open(filename, 'rb')
     try:
-        data = pickle.load(fh)
+        data = sm.cPickle.load(fh)
     finally:
         fh.close()
     return data
 
+
 class FontManager:
     """
     On import, the :class:`FontManager` singleton instance creates a
@@ -1030,24 +1088,19 @@ class FontManager:
         self.default_size = size
 
         paths = []
-        #This allows matplotlib to put fonts in its directory.
-        #Does kiva need this capability? (probably not)
-#        paths = [os.path.join(rcParams['datapath'], 'fonts', 'ttf'),
-#                 os.path.join(rcParams['datapath'], 'fonts', 'afm'),
-#                 os.path.join(rcParams['datapath'], 'fonts', 'pdfcorefonts')]
 
         #  Create list of font paths
         for pathname in ['TTFPATH', 'AFMPATH']:
             if pathname in os.environ:
                 ttfpath = os.environ[pathname]
-                if ttfpath.find(';') >= 0: #win32 style
+                if ttfpath.find(';') >= 0:  # win32 style
                     paths.extend(ttfpath.split(';'))
-                elif ttfpath.find(':') >= 0: # unix style
+                elif ttfpath.find(':') >= 0:  # unix style
                     paths.extend(ttfpath.split(':'))
                 else:
                     paths.append(ttfpath)
 
-        verbose.report('font search path %s'%(str(paths)))
+        logger.debug("font search path %s", six.text_type(paths))
         #  Load TrueType fonts and create font dictionary.
 
         self.ttffiles = findSystemFonts(paths) + findSystemFonts()
@@ -1057,8 +1110,8 @@ class FontManager:
         self.defaultFont = {}
 
         for fname in self.ttffiles:
-            verbose.report('trying fontname %s' % fname, 'debug')
-            if fname.lower().find('vera.ttf')>=0:
+            logger.debug("trying fontname %s", fname)
+            if fname.lower().find('vera.ttf') >= 0:
                 self.defaultFont['ttf'] = fname
                 break
         else:
@@ -1120,7 +1173,7 @@ class FontManager:
         for i, family1 in enumerate(families):
             family1 = family1.lower()
             if family1 in font_family_aliases:
-                if family1 in ('sans', 'sans serif'):
+                if family1 in ('sans', 'sans serif', 'modern'):
                     family1 = 'sans-serif'
                 options = preferred_fonts[family1]
                 options = [x.lower() for x in options]
@@ -1249,7 +1302,7 @@ class FontManager:
             prop = FontProperties(prop)
         fname = prop.get_file()
         if fname is not None:
-            verbose.report('findfont returning %s'%fname, 'debug')
+            logger.debug("findfont returning %s", fname)
             return fname
 
         if fontext == 'afm':
@@ -1268,8 +1321,9 @@ class FontManager:
         best_font = None
 
         for font in fontlist:
+            fname = font.fname
             if (directory is not None and
-                os.path.commonprefix([font.fname, directory]) != directory):
+                    os.path.commonprefix([fname, directory]) != directory):
                 continue
             # Matching family should have highest priority, so it is multiplied
             # by 10.0
@@ -1303,15 +1357,16 @@ class FontManager:
                     UserWarning)
                 result = self.defaultFont[fontext]
         else:
-            verbose.report(
-                'findfont: Matching %s to %s (%s) with score of %f' %
-                (prop, best_font.name, best_font.fname, best_score))
+            logger.debug(
+                "findfont: Matching %s to %s (%s) with score of %f",
+                prop, best_font.name, best_font.fname, best_score
+            )
             result = best_font.fname
 
         if not os.path.isfile(result):
             if rebuild_if_missing:
-                verbose.report(
-                    'findfont: Found a missing font file.  Rebuilding cache.')
+                logger.debug(
+                    "findfont: Found a missing font file.  Rebuilding cache.")
                 _rebuild()
                 return fontManager.findfont(
                     prop, fontext, directory, True, False)
@@ -1324,6 +1379,8 @@ class FontManager:
 
 
 _is_opentype_cff_font_cache = {}
+
+
 def is_opentype_cff_font(filename):
     """
     Returns True if the given font is a Postscript Compact Font Format
@@ -1341,15 +1398,18 @@ def is_opentype_cff_font(filename):
         return result
     return False
 
+
 fontManager = None
 
 _fmcache = os.path.join(get_configdir(), 'fontList.cache')
 
+
 def _rebuild():
     global fontManager
     fontManager = FontManager()
     pickle_dump(fontManager, _fmcache)
-    verbose.report("generated new fontManager")
+    logger.debug("generated new fontManager")
+
 
 # The experimental fontconfig-based backend.
 if USE_FONTCONFIG and sys.platform != 'win32':
@@ -1357,9 +1417,9 @@ if USE_FONTCONFIG and sys.platform != 'win32':
 
     def fc_match(pattern, fontext):
         fontexts = get_fontext_synonyms(fontext)
-        ext = "." + fontext
         try:
-            pipe = subprocess.Popen(['fc-match', '-sv', pattern], stdout=subprocess.PIPE)
+            pipe = subprocess.Popen(['fc-match', '-sv', pattern],
+                                    stdout=subprocess.PIPE)
             output = pipe.communicate()[0]
         except OSError:
             return None
@@ -1391,12 +1451,12 @@ else:
     try:
         fontManager = pickle_load(_fmcache)
         if (not hasattr(fontManager, '_version') or
-            fontManager._version != FontManager.__version__):
+                fontManager._version != FontManager.__version__):
             _rebuild()
         else:
             fontManager.default_size = None
-            verbose.report("Using fontManager instance from %s" % _fmcache)
-    except:
+            logger.debug("Using fontManager instance from %s", _fmcache)
+    except Exception:
         _rebuild()
 
     def findfont(prop, **kw):
