@@ -77,7 +77,7 @@ def pack(format, obj):
             # fixed point conversion
             value = int(round(value*fixes[name]))
         elements.append(value)
-    data = apply(struct.pack, (formatstring,) + tuple(elements))
+    data = struct.pack(formatstring, *elements)
     return data
 
 
