@@ -20,7 +20,7 @@
 from __future__ import absolute_import, print_function
 
 # standard library imports
-from itertools import izip
+import six.moves as sm
 import warnings
 import copy
 from numpy import array, pi
@@ -343,7 +343,7 @@ class GraphicsContext(GraphicsContextBase):
         if self.current_pdf_path is None:
             self.begin_path()
 
-        for start, end in izip(starts, ends):
+        for start, end in sm.zip(starts, ends):
             self.current_pdf_path.moveTo(start[0], start[1])
             self.current_pdf_path.lineTo(end[0], end[1])
             self.current_point = (end[0], end[1])
@@ -575,8 +575,8 @@ class GraphicsContext(GraphicsContextBase):
         # do it nicely (using convert_pixel_format), and if not, we do
         # it brute-force using Agg.
         from reportlab.lib.utils import ImageReader
-        from PIL import Image as PilImage
         from kiva import agg
+        from kiva.compat import pilfromstring, piltostring
 
         if type(img) == type(array([])):
             # Numeric array
@@ -596,10 +596,10 @@ class GraphicsContext(GraphicsContextBase):
             return
 
         # converted_img now holds an Agg graphics context with the image
-        pil_img = PilImage.fromstring(format,
-                                      (converted_img.width(),
-                                       converted_img.height()),
-                                      converted_img.bmp_array.tostring())
+        pil_img = pilfromstring(format,
+                                (converted_img.width(),
+                                 converted_img.height()),
+                                piltostring(converted_img.bmp_array))
 
         if rect is None:
             rect = (0, 0, img.width(), img.height())
@@ -623,9 +623,10 @@ class GraphicsContext(GraphicsContextBase):
         """ Sets the font for the current graphics context.
         """
         # TODO: Make this actually do the right thing
-        if font.face_name == "":
-            font.face_name = "Helvetica"
-        self.gc.setFont(font.face_name, font.size)
+        face_name = font.face_name
+        if face_name == "":
+            face_name = "Helvetica"
+        self.gc.setFont(face_name, font.size)
 
     def get_font(self):
         """ Get the current font """
