@@ -38,7 +38,31 @@ static PyMethodDef mac_context_methods[] = {
     {NULL, NULL}
 };
 
+#if PY_MAJOR_VERSION >= 3
+
+static struct PyModuleDef mac_context_module = {
+    PyModuleDef_HEAD_INIT,
+    "mac_context",        /* m_name */
+    NULL,                 /* m_doc */
+    -1,                   /* m_size */
+    mac_context_methods,  /* m_methods */
+    NULL,                 /* m_reload */
+    NULL,                 /* m_traverse */
+    NULL,                 /* m_clear */
+    NULL                  /* m_free */
+};
+
+PyMODINIT_FUNC
+PyInit_mac_context(void)
+{
+    return PyModule_Create(&mac_context_module);
+}
+
+#else
+
 void initmac_context(void)
 {
     Py_InitModule("mac_context", mac_context_methods);
 }
+
+#endif
