@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-#------------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 # Copyright (c) 2005, Enthought, Inc.
 # All rights reserved.
 #
@@ -11,10 +11,11 @@
 #
 # Author: Enthought, Inc.
 # Description: <Enthought kiva package project>
-#------------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 
 import sys
-import os
+
+from numpy import get_include
 
 
 def configuration(parent_package=None, top_path=None):
@@ -26,10 +27,7 @@ def configuration(parent_package=None, top_path=None):
 
     config.add_subpackage('agg')
     config.add_subpackage('fonttools')
-    config.add_subpackage('fonttools.*')
-    config.add_subpackage('fonttools.*.*')
-    config.add_subpackage('fonttools.*.*.*')
-    config.add_data_files('fonttools/fontTools/*.txt')
+    config.add_subpackage('fonttools.tests')
     config.add_subpackage('trait_defs')
     config.add_subpackage('trait_defs.ui')
     config.add_subpackage('trait_defs.ui.*')
@@ -39,4 +37,8 @@ def configuration(parent_package=None, top_path=None):
 
     config.get_version()
 
+    ext_sources = ['_cython_speedups.cpp', '_hit_test.cpp']
+    config.add_extension('_cython_speedups', sources=ext_sources,
+                         include_dirs=['.', get_include()])
+
     return config
